"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class SessionQuery(google.protobuf.message.Message):
    """*
    This message is used to initialized or request a session.
    @author Alexander McService Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ID_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    SCENE_NAME_FIELD_NUMBER: builtins.int
    TASK_NAME_FIELD_NUMBER: builtins.int
    USERNAME_FIELD_NUMBER: builtins.int
    id: builtins.str
    """/ unique id of a session; will be created by `SessionService`"""
    user_id: builtins.int
    """/ user assigned to the session"""
    scene_name: builtins.str
    """/ location assigned to the session"""
    task_name: builtins.str
    """/ task assigned to the session"""
    username: builtins.str
    """/ resolves assigned `user_id` from `username`"""
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        user_id: builtins.int = ...,
        scene_name: builtins.str = ...,
        task_name: builtins.str = ...,
        username: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "scene_name", b"scene_name", "task_name", b"task_name", "user_id", b"user_id", "username", b"username"]) -> None: ...

global___SessionQuery = SessionQuery
