"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServerToClient(google.protobuf.message.Message):
    """*
    A message to be sent from a server to a tunneled client.
    Clients need to resolve the (local) method name and assign the correct message IDs to responses
    sent back to the server.
    Note that method names may differ depending on the client's language.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METHOD_FIELD_NUMBER: builtins.int
    REQUEST_FIELD_NUMBER: builtins.int
    MESSAGE_ID_FIELD_NUMBER: builtins.int
    method: builtins.str
    """/ Method name in CapitalCase since this is the default proto style"""
    request: builtins.bytes
    """/ A message as a byte string; needs to be parsed and forwarded to the local gRPC server"""
    message_id: builtins.int
    """/ An ID associated with the request; A response must contain the correct ID!"""
    def __init__(
        self,
        *,
        method: builtins.str = ...,
        request: builtins.bytes = ...,
        message_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["message_id", b"message_id", "method", b"method", "request", b"request"]) -> None: ...

global___ServerToClient = ServerToClient
