# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_meta.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2
from avikom.unity import transpose_pb2 as avikom_dot_unity_dot_transpose__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/instruction_meta.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/assistance_level.proto\x1a\x1d\x61vikom/generic/modality.proto\x1a\x1c\x61vikom/unity/transpose.proto\"\xc7\x01\n\x0fInstructionMeta\x12<\n\x10\x61ssistance_level\x18\x01 \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12,\n\nmodal_bias\x18\x02 \x01(\x0b\x32\x18.avikom.generic.Modality\x12\x10\n\x08location\x18\x03 \x01(\t\x12*\n\ttranspose\x18\x04 \x01(\x0b\x32\x17.avikom.unity.Transpose\x12\n\n\x02id\x18\x05 \x01(\tBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_meta_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _INSTRUCTIONMETA._serialized_start=167
  _INSTRUCTIONMETA._serialized_end=366
# @@protoc_insertion_point(module_scope)
