# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/camunda/external_task.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.camunda import variable_pb2 as avikom_dot_camunda_dot_variable__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"avikom/camunda/external_task.proto\x12\x0e\x61vikom.camunda\x1a\x1d\x61vikom/camunda/variable.proto\"\xfe\x02\n\x0c\x45xternalTask\x12\x13\n\x0b\x61\x63tivity_id\x18\x01 \x01(\t\x12\x1c\n\x14\x61\x63tivity_instance_id\x18\x02 \x01(\t\x12\x15\n\rerror_message\x18\x03 \x01(\t\x12\x14\n\x0c\x65xecution_id\x18\x04 \x01(\t\x12\n\n\x02id\x18\x05 \x01(\t\x12\x1c\n\x14lock_expiration_time\x18\x06 \x01(\t\x12\x1d\n\x15process_definition_id\x18\x07 \x01(\t\x12\x1e\n\x16process_definition_key\x18\x08 \x01(\t\x12\x1b\n\x13process_instance_id\x18\t \x01(\t\x12\x11\n\ttenant_id\x18\n \x01(\t\x12\x0f\n\x07retries\x18\x0b \x01(\x05\x12\x11\n\tworker_id\x18\x0c \x01(\t\x12\x10\n\x08priority\x18\r \x01(\x05\x12\x12\n\ntopic_name\x18\x0e \x01(\t\x12+\n\tvariables\x18\x0f \x03(\x0b\x32\x18.avikom.camunda.VariableBl\n\x18\x61pp.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\xaa\x02\x14\x41vikom.Types.Camundab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.camunda.external_task_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\252\002\024Avikom.Types.Camunda'
  _EXTERNALTASK._serialized_start=86
  _EXTERNALTASK._serialized_end=468
# @@protoc_insertion_point(module_scope)
