# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/vision/image_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61vikom/vision/image_info.proto\x12\ravikom.vision\"`\n\tImageInfo\x12\x0c\n\x04size\x18\x01 \x01(\x05\x12\x12\n\nchunk_size\x18\x02 \x01(\x05\x12\x12\n\ncompressed\x18\x03 \x01(\x08\x12\r\n\x05width\x18\x04 \x01(\x05\x12\x0e\n\x06height\x18\x05 \x01(\x05\x42i\n\x17\x61pp.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\xaa\x02\x13\x41vikom.Types.Visionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.vision.image_info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\252\002\023Avikom.Types.Vision'
  _IMAGEINFO._serialized_start=49
  _IMAGEINFO._serialized_end=145
# @@protoc_insertion_point(module_scope)
