"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Modality(google.protobuf.message.Message):
    """*
    A message specifying one of three- or a combination of three interaction modalities supported 
    for, for example, instructions, peers, user_profiles and sessions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VISUAL_FIELD_NUMBER: builtins.int
    AUDITORY_FIELD_NUMBER: builtins.int
    TACTILE_FIELD_NUMBER: builtins.int
    visual: builtins.float
    """/ things you see (Sight)"""
    auditory: builtins.float
    """/ things you hear (Hearing)"""
    tactile: builtins.float
    """/ things you touch/feel (Touch)"""
    def __init__(
        self,
        *,
        visual: builtins.float = ...,
        auditory: builtins.float = ...,
        tactile: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["auditory", b"auditory", "tactile", b"tactile", "visual", b"visual"]) -> None: ...

global___Modality = Modality
