# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/task_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,avikom/assistance/task_storage_service.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a!avikom/assistance/task_step.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\" \n\x10TaskStorageQuery\x12\x0c\n\x04name\x18\x01 \x01(\t\"5\n\tSceneList\x12(\n\x06scenes\x18\x01 \x03(\x0b\x32\x18.avikom.assistance.Scene\"2\n\x08TaskList\x12&\n\x05tasks\x18\x01 \x03(\x0b\x32\x17.avikom.assistance.Task\":\n\x0cTaskStepList\x12*\n\x05steps\x18\x01 \x03(\x0b\x32\x1b.avikom.assistance.TaskStep2\x98\n\n\x12TaskStorageService\x12[\n\x08\x41\x64\x64Scene\x12\x18.avikom.assistance.Scene\x1a\x16.avikom.generic.Result\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/v1/storage/scenes:\x01*\x12{\n\x0bUpdateScene\x12\x18.avikom.assistance.Scene\x1a\x16.avikom.generic.Result\":\x82\xd3\xe4\x93\x02\x34\x32\x12/v1/storage/scenes:\x01*Z\x1b\x32\x19/v1/storage/scenes/{name}\x12l\n\x08GetScene\x12#.avikom.assistance.TaskStorageQuery\x1a\x18.avikom.assistance.Scene\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/storage/scenes/{name}\x12`\n\x0cGetAllScenes\x12\x16.google.protobuf.Empty\x1a\x1c.avikom.assistance.SceneList\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/v1/storage/scenes\x12X\n\x07\x41\x64\x64Task\x12\x17.avikom.assistance.Task\x1a\x16.avikom.generic.Result\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/storage/tasks:\x01*\x12w\n\nUpdateTask\x12\x17.avikom.assistance.Task\x1a\x16.avikom.generic.Result\"8\x82\xd3\xe4\x93\x02\x32\x32\x11/v1/storage/tasks:\x01*Z\x1a\x32\x18/v1/storage/tasks/{name}\x12i\n\x07GetTask\x12#.avikom.assistance.TaskStorageQuery\x1a\x17.avikom.assistance.Task\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/storage/tasks/{name}\x12]\n\x0bGetAllTasks\x12\x16.google.protobuf.Empty\x1a\x1b.avikom.assistance.TaskList\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/storage/tasks\x12`\n\x0b\x41\x64\x64TaskStep\x12\x1b.avikom.assistance.TaskStep\x1a\x16.avikom.generic.Result\"\x1c\x82\xd3\xe4\x93\x02\x16\"\x11/v1/storage/steps:\x01*\x12\x7f\n\x0eUpdateTaskStep\x12\x1b.avikom.assistance.TaskStep\x1a\x16.avikom.generic.Result\"8\x82\xd3\xe4\x93\x02\x32\x32\x11/v1/storage/steps:\x01*Z\x1a\x32\x18/v1/storage/steps/{name}\x12q\n\x0bGetTaskStep\x12#.avikom.assistance.TaskStorageQuery\x1a\x1b.avikom.assistance.TaskStep\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/storage/steps/{name}\x12\x65\n\x0fGetAllTaskSteps\x12\x16.google.protobuf.Empty\x1a\x1f.avikom.assistance.TaskStepList\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/v1/storage/stepsBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.task_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _TASKSTORAGESERVICE.methods_by_name['AddScene']._options = None
  _TASKSTORAGESERVICE.methods_by_name['AddScene']._serialized_options = b'\202\323\344\223\002\027\"\022/v1/storage/scenes:\001*'
  _TASKSTORAGESERVICE.methods_by_name['UpdateScene']._options = None
  _TASKSTORAGESERVICE.methods_by_name['UpdateScene']._serialized_options = b'\202\323\344\223\00242\022/v1/storage/scenes:\001*Z\0332\031/v1/storage/scenes/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetScene']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetScene']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/storage/scenes/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetAllScenes']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetAllScenes']._serialized_options = b'\202\323\344\223\002\024\022\022/v1/storage/scenes'
  _TASKSTORAGESERVICE.methods_by_name['AddTask']._options = None
  _TASKSTORAGESERVICE.methods_by_name['AddTask']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/storage/tasks:\001*'
  _TASKSTORAGESERVICE.methods_by_name['UpdateTask']._options = None
  _TASKSTORAGESERVICE.methods_by_name['UpdateTask']._serialized_options = b'\202\323\344\223\00222\021/v1/storage/tasks:\001*Z\0322\030/v1/storage/tasks/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetTask']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetTask']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/storage/tasks/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetAllTasks']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetAllTasks']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/storage/tasks'
  _TASKSTORAGESERVICE.methods_by_name['AddTaskStep']._options = None
  _TASKSTORAGESERVICE.methods_by_name['AddTaskStep']._serialized_options = b'\202\323\344\223\002\026\"\021/v1/storage/steps:\001*'
  _TASKSTORAGESERVICE.methods_by_name['UpdateTaskStep']._options = None
  _TASKSTORAGESERVICE.methods_by_name['UpdateTaskStep']._serialized_options = b'\202\323\344\223\00222\021/v1/storage/steps:\001*Z\0322\030/v1/storage/steps/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetTaskStep']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetTaskStep']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/storage/steps/{name}'
  _TASKSTORAGESERVICE.methods_by_name['GetAllTaskSteps']._options = None
  _TASKSTORAGESERVICE.methods_by_name['GetAllTaskSteps']._serialized_options = b'\202\323\344\223\002\023\022\021/v1/storage/steps'
  _TASKSTORAGEQUERY._serialized_start=251
  _TASKSTORAGEQUERY._serialized_end=283
  _SCENELIST._serialized_start=285
  _SCENELIST._serialized_end=338
  _TASKLIST._serialized_start=340
  _TASKLIST._serialized_end=390
  _TASKSTEPLIST._serialized_start=392
  _TASKSTEPLIST._serialized_end=450
  _TASKSTORAGESERVICE._serialized_start=453
  _TASKSTORAGESERVICE._serialized_end=1757
# @@protoc_insertion_point(module_scope)
