# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/rasa_message.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import key_value_pair_pb2 as avikom_dot_generic_dot_key__value__pair__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/headset/rasa_message.proto\x12\x0e\x61vikom.headset\x1a#avikom/generic/key_value_pair.proto\"[\n\x0bRasaMessage\x12\x0e\n\x06intent\x18\x01 \x01(\t\x12+\n\x05slots\x18\x02 \x03(\x0b\x32\x1c.avikom.generic.KeyValuePair\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.rasa_message_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _RASAMESSAGE._serialized_start=90
  _RASAMESSAGE._serialized_end=181
# @@protoc_insertion_point(module_scope)
