"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.key_value_pair_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RasaMessage(google.protobuf.message.Message):
    """*
    A RasaMessage provides the intents and slots recognized by rasa for a specific user.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENT_FIELD_NUMBER: builtins.int
    SLOTS_FIELD_NUMBER: builtins.int
    USER_ID_FIELD_NUMBER: builtins.int
    intent: builtins.str
    """/ the recognized intention of the user input"""
    @property
    def slots(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.key_value_pair_pb2.KeyValuePair]:
        """/ additional information extracted from user input as key-value pairs"""
    user_id: builtins.int
    """/ the user who provided the input"""
    def __init__(
        self,
        *,
        intent: builtins.str = ...,
        slots: collections.abc.Iterable[avikom.generic.key_value_pair_pb2.KeyValuePair] | None = ...,
        user_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intent", b"intent", "slots", b"slots", "user_id", b"user_id"]) -> None: ...

global___RasaMessage = RasaMessage
