# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/runtime_step_list.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import runtime_task_step_pb2 as avikom_dot_assistance_dot_runtime__task__step__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)avikom/assistance/runtime_step_list.proto\x12\x11\x61vikom.assistance\x1a)avikom/assistance/runtime_task_step.proto\x1a\x19\x61vikom/generic/peer.proto\"i\n\x0fRuntimeStepList\x12\x31\n\x05steps\x18\x01 \x03(\x0b\x32\".avikom.assistance.RuntimeTaskStep\x12#\n\x05peers\x18\x02 \x03(\x0b\x32\x14.avikom.generic.PeerBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.runtime_step_list_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _RUNTIMESTEPLIST._serialized_start=134
  _RUNTIMESTEPLIST._serialized_end=239
# @@protoc_insertion_point(module_scope)
