# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tracking/gaze_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\"avikom/tracking/gaze_service.proto\x12\x0f\x61vikom.tracking\x1a\x1bgoogle/protobuf/empty.proto\"\x18\n\nGazeTarget\x12\n\n\x02id\x18\x01 \x01(\t2W\n\x0bGazeService\x12H\n\rFocusedObject\x12\x16.google.protobuf.Empty\x1a\x1b.avikom.tracking.GazeTarget\"\x00\x30\x01\x42o\n\x19\x61pp.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\xaa\x02\x15\x41vikom.Types.Trackingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tracking.gaze_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031app.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\252\002\025Avikom.Types.Tracking'
  _GAZETARGET._serialized_start=84
  _GAZETARGET._serialized_end=108
  _GAZESERVICE._serialized_start=110
  _GAZESERVICE._serialized_end=197
# @@protoc_insertion_point(module_scope)
