"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _CommonUtterance:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _CommonUtteranceEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_CommonUtterance.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    COMMON_UTTERANCE_DEFAULT: _CommonUtterance.ValueType  # 0
    """/ generates no output"""
    COMMON_UTTERANCE_REPEAT: _CommonUtterance.ValueType  # 1
    """/ repeats the last speech output"""
    COMMON_UTTERANCE_APPROVE: _CommonUtterance.ValueType  # 2
    """/ utters a statement of confirmation i.e. "Ja" """
    COMMON_UTTERANCE_COMPLIMENT: _CommonUtterance.ValueType  # 3
    """/ utters a compliment i.e. "Toll! Weiter so." """

class CommonUtterance(_CommonUtterance, metaclass=_CommonUtteranceEnumTypeWrapper):
    """*
    This enum describes common utterances to be generated by the TTs engine and played back 
    on an auditory peer. 
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

COMMON_UTTERANCE_DEFAULT: CommonUtterance.ValueType  # 0
"""/ generates no output"""
COMMON_UTTERANCE_REPEAT: CommonUtterance.ValueType  # 1
"""/ repeats the last speech output"""
COMMON_UTTERANCE_APPROVE: CommonUtterance.ValueType  # 2
"""/ utters a statement of confirmation i.e. "Ja" """
COMMON_UTTERANCE_COMPLIMENT: CommonUtterance.ValueType  # 3
"""/ utters a compliment i.e. "Toll! Weiter so." """
global___CommonUtterance = CommonUtterance
