"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class User(google.protobuf.message.Message):
    """*
    A message that contains data about a user that is essential for system operation.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FIRST_NAME_FIELD_NUMBER: builtins.int
    LAST_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    USERNAMES_FIELD_NUMBER: builtins.int
    first_name: builtins.str
    """/ the first name is optional; will default to empty string if not"""
    last_name: builtins.str
    """/ the last name is optional; will default to empty string if not set"""
    id: builtins.int
    """/ does not need to be set when a new user is created"""
    @property
    def usernames(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ system usernames required for certain peers, preferarbly unique to prevent imposters"""
    def __init__(
        self,
        *,
        first_name: builtins.str = ...,
        last_name: builtins.str = ...,
        id: builtins.int = ...,
        usernames: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["first_name", b"first_name", "id", b"id", "last_name", b"last_name", "usernames", b"usernames"]) -> None: ...

global___User = User
