# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/logger_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/generic/logger_service.proto\x12\x0e\x61vikom.generic\x1a\x1b\x61vikom/generic/result.proto\x1a\x1cgoogle/api/annotations.proto\"S\n\x07Message\x12\'\n\x05level\x18\x01 \x01(\x0e\x32\x18.avikom.generic.LogLevel\x12\x0f\n\x07\x63ontent\x18\x02 \x01(\t\x12\x0e\n\x06origin\x18\x03 \x01(\t*?\n\x08LogLevel\x12\t\n\x05\x44\x45\x42UG\x10\x00\x12\x08\n\x04INFO\x10\x01\x12\x08\n\x04WARN\x10\x02\x12\t\n\x05\x45RROR\x10\x03\x12\t\n\x05\x46\x41TAL\x10\x04\x32\x95\x01\n\rLoggerService\x12\x83\x01\n\x03Log\x12\x17.avikom.generic.Message\x1a\x16.avikom.generic.Result\"K\x82\xd3\xe4\x93\x02\x45\"\n/v1/logger:\x01*Z\x15\"\x13/v1/logger/{origin}Z\x1d\"\x1b/v1/logger/{origin}/{level}Bl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.logger_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _LOGGERSERVICE.methods_by_name['Log']._options = None
  _LOGGERSERVICE.methods_by_name['Log']._serialized_options = b'\202\323\344\223\002E\"\n/v1/logger:\001*Z\025\"\023/v1/logger/{origin}Z\035\"\033/v1/logger/{origin}/{level}'
  _LOGLEVEL._serialized_start=199
  _LOGLEVEL._serialized_end=262
  _MESSAGE._serialized_start=114
  _MESSAGE._serialized_end=197
  _LOGGERSERVICE._serialized_start=265
  _LOGGERSERVICE._serialized_end=414
# @@protoc_insertion_point(module_scope)
