# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/content_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/generic/content_type.proto\x12\x0e\x61vikom.generic*\xa9\x01\n\x0b\x43ontentType\x12\x13\n\x0f\x43ONTENT_UNKNOWN\x10\x00\x12\x11\n\rCONTENT_IMAGE\x10\x01\x12\x11\n\rCONTENT_VIDEO\x10\x02\x12\x10\n\x0c\x43ONTENT_TEXT\x10\x03\x12\x11\n\rCONTENT_AUDIO\x10\x04\x12\x12\n\x0e\x43ONTENT_VISUAL\x10\x05\x12\x14\n\x10\x43ONTENT_EXTERNAL\x10\x06\x12\x10\n\x0c\x43ONTENT_SSML\x10\x07\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.content_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _CONTENTTYPE._serialized_start=54
  _CONTENTTYPE._serialized_end=223
# @@protoc_insertion_point(module_scope)
