# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/user_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import user_profile_pb2 as avikom_dot_generic_dot_user__profile__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/generic/user_service.proto\x12\x0e\x61vikom.generic\x1a\x19\x61vikom/generic/user.proto\x1a!avikom/generic/user_profile.proto\x1a\x1cgoogle/api/annotations.proto2\x80\x04\n\x0bUserService\x12\xc5\x01\n\x07GetInfo\x12\x14.avikom.generic.User\x1a\x14.avikom.generic.User\"\x8d\x01\x82\xd3\xe4\x93\x02\x86\x01\x12\x11/v1/users/id/{id}Z#\x12!/v1/users/first_name/{first_name}Z!\x12\x1f/v1/users/last_name/{last_name}Z)\x12\'/v1/users/name/{first_name}/{last_name}\x12\xdb\x01\n\nGetProfile\x12\x14.avikom.generic.User\x1a\x1b.avikom.generic.UserProfile\"\x99\x01\x82\xd3\xe4\x93\x02\x92\x01\x12\x14/v1/profiles/id/{id}Z&\x12$/v1/profiles/first_name/{first_name}Z$\x12\"/v1/profiles/last_name/{last_name}Z,\x12*/v1/profiles/name/{first_name}/{last_name}\x12K\n\x07\x41\x64\x64User\x12\x14.avikom.generic.User\x1a\x14.avikom.generic.User\"\x14\x82\xd3\xe4\x93\x02\x0e\"\t/v1/users:\x01*Bl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.user_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _USERSERVICE.methods_by_name['GetInfo']._options = None
  _USERSERVICE.methods_by_name['GetInfo']._serialized_options = b'\202\323\344\223\002\206\001\022\021/v1/users/id/{id}Z#\022!/v1/users/first_name/{first_name}Z!\022\037/v1/users/last_name/{last_name}Z)\022\'/v1/users/name/{first_name}/{last_name}'
  _USERSERVICE.methods_by_name['GetProfile']._options = None
  _USERSERVICE.methods_by_name['GetProfile']._serialized_options = b'\202\323\344\223\002\222\001\022\024/v1/profiles/id/{id}Z&\022$/v1/profiles/first_name/{first_name}Z$\022\"/v1/profiles/last_name/{last_name}Z,\022*/v1/profiles/name/{first_name}/{last_name}'
  _USERSERVICE.methods_by_name['AddUser']._options = None
  _USERSERVICE.methods_by_name['AddUser']._serialized_options = b'\202\323\344\223\002\016\"\t/v1/users:\001*'
  _USERSERVICE._serialized_start=146
  _USERSERVICE._serialized_end=658
# @@protoc_insertion_point(module_scope)
