# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/audio_peer_control_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.headset import functional_sound_pb2 as avikom_dot_headset_dot_functional__sound__pb2
from avikom.headset import common_utterance_pb2 as avikom_dot_headset_dot_common__utterance__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/headset/audio_peer_control_service.proto\x12\x0e\x61vikom.headset\x1a\x1b\x61vikom/generic/result.proto\x1a%avikom/headset/functional_sound.proto\x1a%avikom/headset/common_utterance.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\":\n\x14\x41udioPeerModeRequest\x12\"\n\x04mode\x18\x02 \x01(\x0e\x32\x14.avikom.headset.Mode\"h\n\x16\x46unctionalSoundRequest\x12\x39\n\x10\x66unctional_sound\x18\x02 \x01(\x0e\x32\x1f.avikom.headset.FunctionalSound\x12\x13\n\x0bother_sound\x18\x03 \x01(\t\"Z\n\nSayRequest\x12\x11\n\tutterance\x18\x02 \x01(\t\x12\x39\n\x10\x63ommon_utterance\x18\x03 \x01(\x0e\x32\x1f.avikom.headset.CommonUtterance*@\n\x04Mode\x12\x10\n\x0cMODE_UNKNOWN\x10\x00\x12\x10\n\x0cMODE_DEFAULT\x10\x01\x12\x14\n\x10MODE_TRANSPARENT\x10\x02\x32\xf0\x01\n\x17\x41udioPeerControlService\x12I\n\x07SetMode\x12$.avikom.headset.AudioPeerModeRequest\x1a\x16.avikom.generic.Result\"\x00\x12M\n\tPlaySound\x12&.avikom.headset.FunctionalSoundRequest\x1a\x16.avikom.generic.Result\"\x00\x12;\n\x03Say\x12\x1a.avikom.headset.SayRequest\x1a\x16.avikom.generic.Result\"\x00\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.audio_peer_control_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _MODE._serialized_start=491
  _MODE._serialized_end=555
  _AUDIOPEERMODEREQUEST._serialized_start=233
  _AUDIOPEERMODEREQUEST._serialized_end=291
  _FUNCTIONALSOUNDREQUEST._serialized_start=293
  _FUNCTIONALSOUNDREQUEST._serialized_end=397
  _SAYREQUEST._serialized_start=399
  _SAYREQUEST._serialized_end=489
  _AUDIOPEERCONTROLSERVICE._serialized_start=558
  _AUDIOPEERCONTROLSERVICE._serialized_end=798
# @@protoc_insertion_point(module_scope)
