# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/scene_config_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.unity import scene_config_pb2 as avikom_dot_unity_dot_scene__config__pb2
from avikom.unity import task_config_pb2 as avikom_dot_unity_dot_task__config__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/unity/scene_config_storage_service.proto\x12\x0c\x61vikom.unity\x1a\x1b\x61vikom/generic/result.proto\x1a\x1f\x61vikom/unity/scene_config.proto\x1a\x1e\x61vikom/unity/task_config.proto\x1a\x1cgoogle/api/annotations.proto\"&\n\x10SceneConfigQuery\x12\x12\n\nscene_name\x18\x01 \x01(\t\"$\n\x0fTaskConfigQuery\x12\x11\n\ttask_name\x18\x01 \x01(\t2\xd4\x03\n\x19SceneConfigStorageService\x12\x45\n\x0e\x41\x64\x64SceneConfig\x12\x19.avikom.unity.SceneConfig\x1a\x16.avikom.generic.Result\"\x00\x12M\n\x0eGetSceneConfig\x12\x1e.avikom.unity.SceneConfigQuery\x1a\x19.avikom.unity.SceneConfig\"\x00\x12H\n\x11UpdateSceneConfig\x12\x19.avikom.unity.SceneConfig\x1a\x16.avikom.generic.Result\"\x00\x12\x43\n\rAddTaskConfig\x12\x18.avikom.unity.TaskConfig\x1a\x16.avikom.generic.Result\"\x00\x12J\n\rGetTaskConfig\x12\x1d.avikom.unity.TaskConfigQuery\x1a\x18.avikom.unity.TaskConfig\"\x00\x12\x46\n\x10UpdateTaskConfig\x12\x18.avikom.unity.TaskConfig\x1a\x16.avikom.generic.Result\"\x00\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.scene_config_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _SCENECONFIGQUERY._serialized_start=189
  _SCENECONFIGQUERY._serialized_end=227
  _TASKCONFIGQUERY._serialized_start=229
  _TASKCONFIGQUERY._serialized_end=265
  _SCENECONFIGSTORAGESERVICE._serialized_start=268
  _SCENECONFIGSTORAGESERVICE._serialized_end=736
# @@protoc_insertion_point(module_scope)
