# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/interaction_type.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/glasses/interaction_type.proto\x12\x0e\x61vikom.glasses\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto*\xc4\x01\n\x0fInteractionType\x12\x17\n\x13INTERACTION_UNKNOWN\x10\x00\x12\x13\n\x0fINTERACTION_TAP\x10\x01\x12\x14\n\x10INTERACTION_HOME\x10\x02\x12\x1b\n\x17INTERACTION_BUTTON_DOWN\x10\x03\x12\x19\n\x15INTERACTION_BUTTON_UP\x10\x04\x12\x1a\n\x16INTERACTION_DRAG_START\x10\x05\x12\x19\n\x15INTERACTION_DRAG_STOP\x10\x06\x42l\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.interaction_type_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _INTERACTIONTYPE._serialized_start=146
  _INTERACTIONTYPE._serialized_end=342
# @@protoc_insertion_point(module_scope)
