# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/vision/image_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.vision import image_info_pb2 as avikom_dot_vision_dot_image__info__pb2
from avikom.vision import image_pb2 as avikom_dot_vision_dot_image__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/vision/image_service.proto\x12\ravikom.vision\x1a\x1e\x61vikom/vision/image_info.proto\x1a\x19\x61vikom/vision/image.proto2\x8e\x01\n\x0cImageService\x12>\n\x08GetImage\x12\x18.avikom.vision.ImageInfo\x1a\x14.avikom.vision.Image\"\x00\x30\x01\x12>\n\x08GetVideo\x12\x18.avikom.vision.ImageInfo\x1a\x14.avikom.vision.Image\"\x00\x30\x01\x42i\n\x17\x61pp.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\xaa\x02\x13\x41vikom.Types.Visionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.vision.image_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\252\002\023Avikom.Types.Vision'
  _IMAGESERVICE._serialized_start=112
  _IMAGESERVICE._serialized_end=254
# @@protoc_insertion_point(module_scope)
