# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/stream_request.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/generic/stream_request.proto\x12\x0e\x61vikom.generic\x1a\x1b\x61vikom/generic/result.proto\x1a\x19\x61vikom/generic/peer.proto\x1a\x1bgoogle/protobuf/empty.proto\"\xeb\x01\n\rStreamRequest\x12*\n\x08protocol\x18\x01 \x01(\x0e\x32\x18.avikom.generic.Protocol\x12\x33\n\raudio_quality\x18\x02 \x01(\x0e\x32\x1c.avikom.generic.AudioQuality\x12\x33\n\rvideo_quality\x18\x03 \x01(\x0e\x32\x1c.avikom.generic.VideoQuality\x12\x16\n\x0esend_augmented\x18\x04 \x01(\x08\x12\x15\n\rreceive_audio\x18\x05 \x01(\x08\x12\x15\n\rreceive_video\x18\x06 \x01(\x08*4\n\x08Protocol\x12\x10\n\x0cPROTOCOL_TCP\x10\x00\x12\x16\n\x12PROTOCOL_WEBSOCKET\x10\x01*v\n\x0cVideoQuality\x12\x16\n\x12QUALITY_VIDEO_NONE\x10\x00\x12\x18\n\x14QUALITY_VIDEO_LOWEST\x10\x01\x12\x19\n\x15QUALITY_VIDEO_DEFAULT\x10\x05\x12\x19\n\x15QUALITY_VIDEO_HIGHEST\x10\n*v\n\x0c\x41udioQuality\x12\x16\n\x12QUALITY_AUDIO_NONE\x10\x00\x12\x18\n\x14QUALITY_AUDIO_LOWEST\x10\x01\x12\x19\n\x15QUALITY_AUDIO_DEFAULT\x10\x05\x12\x19\n\x15QUALITY_AUDIO_HIGHEST\x10\n2\xa3\x01\n\x14StreamRequestService\x12\x43\n\nInitStream\x12\x1d.avikom.generic.StreamRequest\x1a\x14.avikom.generic.Peer\"\x00\x12\x46\n\x0b\x43loseStream\x12\x1d.avikom.generic.StreamRequest\x1a\x16.google.protobuf.Empty\"\x00\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.stream_request_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _PROTOCOL._serialized_start=378
  _PROTOCOL._serialized_end=430
  _VIDEOQUALITY._serialized_start=432
  _VIDEOQUALITY._serialized_end=550
  _AUDIOQUALITY._serialized_start=552
  _AUDIOQUALITY._serialized_end=670
  _STREAMREQUEST._serialized_start=141
  _STREAMREQUEST._serialized_end=376
  _STREAMREQUESTSERVICE._serialized_start=673
  _STREAMREQUESTSERVICE._serialized_end=836
# @@protoc_insertion_point(module_scope)
