# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/camunda/variable.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61vikom/camunda/variable.proto\x12\x0e\x61vikom.camunda\"V\n\x08Variable\x12\x0c\n\x04name\x18\x01 \x01(\t\x12-\n\nvalue_type\x18\x02 \x01(\x0e\x32\x19.avikom.camunda.ValueType\x12\r\n\x05value\x18\x03 \x01(\t*O\n\tValueType\x12\x0e\n\nTYPE_UNSET\x10\x00\x12\x0f\n\x0bTYPE_STRING\x10\x01\x12\x0f\n\x0bTYPE_NUMBER\x10\x02\x12\x10\n\x0cTYPE_BOOLEAN\x10\x03\x42l\n\x18\x61pp.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\xaa\x02\x14\x41vikom.Types.Camundab\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.camunda.variable_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.camundaZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/camunda\252\002\024Avikom.Types.Camunda'
  _VALUETYPE._serialized_start=137
  _VALUETYPE._serialized_end=216
  _VARIABLE._serialized_start=49
  _VARIABLE._serialized_end=135
# @@protoc_insertion_point(module_scope)
