# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/calibration_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/glasses/calibration_service.proto\x12\x0e\x61vikom.glasses\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto\"\x1e\n\rSpacePinNames\x12\r\n\x05names\x18\x01 \x03(\t2\xb0\x01\n\x12\x43\x61librationService\x12M\n\x17GetUncalibratedSpacePin\x12\x16.google.protobuf.Empty\x1a\x18.avikom.unity.GameObject\"\x00\x12K\n\x10GetSpacePinNames\x12\x16.google.protobuf.Empty\x1a\x1d.avikom.glasses.SpacePinNames\"\x00\x42l\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.calibration_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _SPACEPINNAMES._serialized_start=151
  _SPACEPINNAMES._serialized_end=181
  _CALIBRATIONSERVICE._serialized_start=184
  _CALIBRATIONSERVICE._serialized_end=360
# @@protoc_insertion_point(module_scope)
