# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/task_stereotype.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import service_configuration_pb2 as avikom_dot_assistance_dot_service__configuration__pb2
from avikom.assistance import choices_config_pb2 as avikom_dot_assistance_dot_choices__config__pb2
from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'avikom/assistance/task_stereotype.proto\x12\x11\x61vikom.assistance\x1a-avikom/assistance/service_configuration.proto\x1a&avikom/assistance/choices_config.proto\x1a(avikom/assistance/assistance_level.proto\x1a\x1e\x61vikom/unity/game_object.proto\"\xe8\x02\n\x0eTaskStereotype\x12;\n\x08\x63\x61tegory\x18\x01 \x01(\x0e\x32).avikom.assistance.TaskStereotypeCategory\x12\x31\n\x07\x63hoices\x18\x05 \x01(\x0b\x32 .avikom.assistance.ChoicesConfig\x12\x0e\n\x06target\x18\x06 \x01(\t\x12\x39\n\x08services\x18\x07 \x03(\x0b\x32\'.avikom.assistance.ServiceConfiguration\x12>\n\x12\x64\x65\x66\x61ult_assistance\x18\n \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12>\n\x12minimal_assistance\x18\x0b \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12\x1b\n\x13\x61ssistance_decrease\x18\x0c \x01(\x02*\xa4\x01\n\x16TaskStereotypeCategory\x12\x0f\n\x0bTASK_UNKOWN\x10\x00\x12\x10\n\x0cTASK_PENDING\x10\x01\x12\x11\n\rTASK_DECISION\x10\x02\x12\x0f\n\x0bTASK_ASSIGN\x10\x03\x12\x0e\n\nTASK_GUIDE\x10\x04\x12\x10\n\x0cTASK_APPROVE\x10\x05\x12\x0e\n\nTASK_INPUT\x10\x06\x12\x11\n\rTASK_INTERNAL\x10\x07\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.task_stereotype_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _TASKSTEREOTYPECATEGORY._serialized_start=587
  _TASKSTEREOTYPECATEGORY._serialized_end=751
  _TASKSTEREOTYPE._serialized_start=224
  _TASKSTEREOTYPE._serialized_end=584
# @@protoc_insertion_point(module_scope)
