"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.runtime_task_step_pb2
import avikom.generic.peer_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RuntimeStepList(google.protobuf.message.Message):
    """*
    A list of `RuntimeTaskSteps`. It also contains a list of `Peers` which can be used to conduct the passed steps.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEPS_FIELD_NUMBER: builtins.int
    PEERS_FIELD_NUMBER: builtins.int
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.runtime_task_step_pb2.RuntimeTaskStep]:
        """/ currently active task steps to be done"""
    @property
    def peers(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.peer_pb2.Peer]:
        """/ a list of peers that can be used to solve task steps"""
    def __init__(
        self,
        *,
        steps: collections.abc.Iterable[avikom.assistance.runtime_task_step_pb2.RuntimeTaskStep] | None = ...,
        peers: collections.abc.Iterable[avikom.generic.peer_pb2.Peer] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["peers", b"peers", "steps", b"steps"]) -> None: ...

global___RuntimeStepList = RuntimeStepList
