# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/task_step.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_stereotype_pb2 as avikom_dot_assistance_dot_task__stereotype__pb2
from avikom.assistance import instruction_text_pb2 as avikom_dot_assistance_dot_instruction__text__pb2
from avikom.assistance import instruction_media_pb2 as avikom_dot_assistance_dot_instruction__media__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/assistance/task_step.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\'avikom/assistance/task_stereotype.proto\x1a(avikom/assistance/instruction_text.proto\x1a)avikom/assistance/instruction_media.proto\"\xc5\x01\n\x08TaskStep\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12/\n\x04type\x18\x03 \x01(\x0b\x32!.avikom.assistance.TaskStereotype\x12\x38\n\x0cinstructions\x18\x04 \x03(\x0b\x32\".avikom.assistance.InstructionText\x12\x32\n\x05media\x18\x05 \x03(\x0b\x32#.avikom.assistance.InstructionMedia:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.task_step_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _TASKSTEP.fields_by_name['name']._options = None
  _TASKSTEP.fields_by_name['name']._serialized_options = b'\212\265\030\002\020\001'
  _TASKSTEP._options = None
  _TASKSTEP._serialized_options = b'\210\265\030\001'
  _TASKSTEP._serialized_start=213
  _TASKSTEP._serialized_end=410
# @@protoc_insertion_point(module_scope)
