# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/peer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import rpc_endpoint_pb2 as avikom_dot_generic_dot_rpc__endpoint__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61vikom/generic/peer.proto\x12\x0e\x61vikom.generic\x1a\x1c\x61vikom/options/options.proto\x1a!avikom/generic/rpc_endpoint.proto\x1a\x19\x61vikom/generic/user.proto\x1a\x1d\x61vikom/generic/modality.proto\"\xf7\x01\n\x04Peer\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x11\n\thost_name\x18\x03 \x01(\t\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\"\n\x04user\x18\x06 \x01(\x0b\x32\x14.avikom.generic.User\x12/\n\rmodal_fitness\x18\x07 \x01(\x0b\x32\x18.avikom.generic.Modality\x12\x0f\n\x07gateway\x18\x08 \x01(\t\x12\x10\n\x08services\x18\n \x03(\t\x12.\n\tendpoints\x18\x0b \x03(\x0e\x32\x1b.avikom.generic.RpcEndpoint:\x04\x88\xb5\x18\x01\"/\n\x08PeerList\x12#\n\x05peers\x18\x01 \x03(\x0b\x32\x14.avikom.generic.PeerBl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.peer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _PEER.fields_by_name['name']._options = None
  _PEER.fields_by_name['name']._serialized_options = b'\212\265\030\002\020\001'
  _PEER._options = None
  _PEER._serialized_options = b'\210\265\030\001'
  _PEER._serialized_start=169
  _PEER._serialized_end=416
  _PEERLIST._serialized_start=418
  _PEERLIST._serialized_end=465
# @@protoc_insertion_point(module_scope)
