# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/options/options.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import descriptor_pb2 as google_dot_protobuf_dot_descriptor__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61vikom/options/options.proto\x12\x0e\x61vikom.options\x1a google/protobuf/descriptor.proto\"\x81\x01\n\x0c\x46ieldOptions\x12\r\n\x05index\x18\x01 \x01(\x08\x12\x0e\n\x06unique\x18\x02 \x01(\x08\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x03 \x01(\t\x12\r\n\x05match\x18\x04 \x01(\t\x12\x0b\n\x03min\x18\x05 \x01(\t\x12\x11\n\timmutable\x18\x06 \x01(\x08\x12\x12\n\nauto_index\x18\x07 \x01(\x08:M\n\x06schema\x12\x1d.google.protobuf.FieldOptions\x18\xd1\x86\x03 \x01(\x0b\x32\x1c.avikom.options.FieldOptions:<\n\x11schema_definition\x12\x1f.google.protobuf.MessageOptions\x18\xd1\x86\x03 \x01(\x08\x42l\n\x18\x61pp.avikom.types.optionsZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/options\xaa\x02\x14\x41vikom.Types.Optionsb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.options.options_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:
  google_dot_protobuf_dot_descriptor__pb2.FieldOptions.RegisterExtension(schema)
  google_dot_protobuf_dot_descriptor__pb2.MessageOptions.RegisterExtension(schema_definition)

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.optionsZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/options\252\002\024Avikom.Types.Options'
  _FIELDOPTIONS._serialized_start=83
  _FIELDOPTIONS._serialized_end=212
# @@protoc_insertion_point(module_scope)
