"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.task_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Scene(google.protobuf.message.Message):
    """*
    Describes the location/context of a task. This might be an office or a lab.
    The `tasks` field should only contain tasks that can be intialized without further information.
    For instance, when a task requires to be prepened by another task, it should be mentioned here.
    Thus, an `Issue` might contain a task that is not mentioned in `Session.tasks`.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    TASKS_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ a unique name for the location/context"""
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_pb2.Task]:
        """all the tasks that can be conducted without further information"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        tasks: collections.abc.Iterable[avikom.assistance.task_pb2.Task] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name", "tasks", b"tasks"]) -> None: ...

global___Scene = Scene
