"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.content_type_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class MediaInfo(google.protobuf.message.Message):
    """*
    This message describes a media file, it's name (or file path), its content type (e.g. video, audio, image) and the current playback time if applicable.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MEDIA_NAME_FIELD_NUMBER: builtins.int
    CONTENT_TYPE_FIELD_NUMBER: builtins.int
    MILLISECONDS_FIELD_NUMBER: builtins.int
    media_name: builtins.str
    """/ media name, identifier or file path"""
    content_type: avikom.generic.content_type_pb2.ContentType.ValueType
    """/ the content type, e.g. video, image or audio"""
    milliseconds: builtins.int
    """/ the current playback time location; not applicable for images etc."""
    def __init__(
        self,
        *,
        media_name: builtins.str = ...,
        content_type: avikom.generic.content_type_pb2.ContentType.ValueType = ...,
        milliseconds: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content_type", b"content_type", "media_name", b"media_name", "milliseconds", b"milliseconds"]) -> None: ...

global___MediaInfo = MediaInfo
