# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/math/float_matrix.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.math import float_array_pb2 as avikom_dot_math_dot_float__array__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61vikom/math/float_matrix.proto\x12\x0b\x61vikom.math\x1a\x1d\x61vikom/math/float_array.proto\"4\n\x0b\x46loatMatrix\x12%\n\x04rows\x18\x01 \x03(\x0b\x32\x17.avikom.math.FloatArrayBc\n\x15\x61pp.avikom.types.mathZ6gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/math\xaa\x02\x11\x41vikom.Types.Mathb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.math.float_matrix_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\025app.avikom.types.mathZ6gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/math\252\002\021Avikom.Types.Math'
  _FLOATMATRIX._serialized_start=78
  _FLOATMATRIX._serialized_end=130
# @@protoc_insertion_point(module_scope)
