# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/key_value_pair.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/generic/key_value_pair.proto\x12\x0e\x61vikom.generic\"*\n\x0cKeyValuePair\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\tBl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.key_value_pair_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _KEYVALUEPAIR._serialized_start=55
  _KEYVALUEPAIR._serialized_end=97
# @@protoc_insertion_point(module_scope)
