# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/asset_bundle_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'avikom/unity/asset_bundle_service.proto\x12\x0c\x61vikom.unity\x1a\x1f\x61vikom/unity/asset_bundle.proto\x1a\x1cgoogle/api/annotations.proto\"\'\n\x10\x41ssetBundleQuery\x12\x13\n\x0b\x62undle_name\x18\x01 \x01(\t2Z\n\x12\x41ssetBundleService\x12\x44\n\x03Get\x12\x1e.avikom.unity.AssetBundleQuery\x1a\x19.avikom.unity.AssetBundle\"\x00\x30\x01\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.asset_bundle_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _ASSETBUNDLEQUERY._serialized_start=120
  _ASSETBUNDLEQUERY._serialized_end=159
  _ASSETBUNDLESERVICE._serialized_start=161
  _ASSETBUNDLESERVICE._serialized_end=251
# @@protoc_insertion_point(module_scope)
