# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/scene_config.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from avikom.unity import waypoint_pb2 as avikom_dot_unity_dot_waypoint__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61vikom/unity/scene_config.proto\x12\x0c\x61vikom.unity\x1a\x1c\x61vikom/options/options.proto\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1b\x61vikom/unity/waypoint.proto\"\xaf\x01\n\x0bSceneConfig\x12\x1a\n\nscene_name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12)\n\x07\x61nchors\x18\x02 \x03(\x0b\x32\x18.avikom.unity.GameObject\x12(\n\x06\x61ssets\x18\x03 \x03(\x0b\x32\x18.avikom.unity.GameObject\x12)\n\twaypoints\x18\x04 \x03(\x0b\x32\x16.avikom.unity.Waypoint:\x04\x88\xb5\x18\x01\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.scene_config_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _SCENECONFIG.fields_by_name['scene_name']._options = None
  _SCENECONFIG.fields_by_name['scene_name']._serialized_options = b'\212\265\030\002\020\001'
  _SCENECONFIG._options = None
  _SCENECONFIG._serialized_options = b'\210\265\030\001'
  _SCENECONFIG._serialized_start=141
  _SCENECONFIG._serialized_end=316
# @@protoc_insertion_point(module_scope)
