# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/nlp/answer_question_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/nlp/answer_question_service.proto\x12\navikom.nlp\"8\n\x13\x41nswerQuestionQuery\x12\x0f\n\x07\x63ontext\x18\x01 \x01(\t\x12\x10\n\x08question\x18\x02 \x01(\t\"S\n\x16\x41nswerQuestionResponse\x12\r\n\x05score\x18\x01 \x01(\x02\x12\r\n\x05start\x18\x02 \x01(\x05\x12\x0b\n\x03\x65nd\x18\x03 \x01(\x05\x12\x0e\n\x06\x61nswer\x18\x04 \x01(\t2p\n\x15\x41nswerQuestionService\x12W\n\x0e\x41nswerQuestion\x12\x1f.avikom.nlp.AnswerQuestionQuery\x1a\".avikom.nlp.AnswerQuestionResponse\"\x00\x42`\n\x14\x61pp.avikom.types.nlpZ5gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/nlp\xaa\x02\x10\x41vikom.Types.Nlpb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.nlp.answer_question_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024app.avikom.types.nlpZ5gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/nlp\252\002\020Avikom.Types.Nlp'
  _ANSWERQUESTIONQUERY._serialized_start=56
  _ANSWERQUESTIONQUERY._serialized_end=112
  _ANSWERQUESTIONRESPONSE._serialized_start=114
  _ANSWERQUESTIONRESPONSE._serialized_end=197
  _ANSWERQUESTIONSERVICE._serialized_start=199
  _ANSWERQUESTIONSERVICE._serialized_end=311
# @@protoc_insertion_point(module_scope)
