"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ImageInfo(google.protobuf.message.Message):
    """*
    This message is a header for image data transfer in chunks.
    It should always be set in the first `Image` message send to an image receiver.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CHUNK_SIZE_FIELD_NUMBER: builtins.int
    COMPRESSED_FIELD_NUMBER: builtins.int
    WIDTH_FIELD_NUMBER: builtins.int
    HEIGHT_FIELD_NUMBER: builtins.int
    size: builtins.int
    """/ size of the image in bytes"""
    chunk_size: builtins.int
    """/ transfer chunk size in bytes"""
    compressed: builtins.bool
    """/ whether the image has been compressed or send raw; NOTE: this field is not considered right now by the `ImageService`"""
    width: builtins.int
    """/ pixel width of the image"""
    height: builtins.int
    """/ pixel height of the image"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
        chunk_size: builtins.int = ...,
        compressed: builtins.bool = ...,
        width: builtins.int = ...,
        height: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["chunk_size", b"chunk_size", "compressed", b"compressed", "height", b"height", "size", b"size", "width", b"width"]) -> None: ...

global___ImageInfo = ImageInfo
