# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_media.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import instruction_meta_pb2 as avikom_dot_assistance_dot_instruction__meta__pb2
from avikom.assistance import instruction_media_value_pb2 as avikom_dot_assistance_dot_instruction__media__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)avikom/assistance/instruction_media.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/instruction_meta.proto\x1a/avikom/assistance/instruction_media_value.proto\"\xba\x01\n\x10InstructionMedia\x12\x30\n\x04meta\x18\x01 \x01(\x0b\x32\".avikom.assistance.InstructionMeta\x12\x39\n\x07\x63ontent\x18\x0b \x01(\x0b\x32(.avikom.assistance.InstructionMediaValue\x12\x39\n\x07preview\x18\x0c \x01(\x0b\x32(.avikom.assistance.InstructionMediaValueBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_media_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _INSTRUCTIONMEDIA._serialized_start=156
  _INSTRUCTIONMEDIA._serialized_end=342
# @@protoc_insertion_point(module_scope)
