# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2
from avikom.assistance import instruction_text_pb2 as avikom_dot_assistance_dot_instruction__text__pb2
from avikom.assistance import instruction_media_pb2 as avikom_dot_assistance_dot_instruction__media__pb2
from avikom.assistance import runtime_step_list_pb2 as avikom_dot_assistance_dot_runtime__step__list__pb2
from avikom.assistance import session_pb2 as avikom_dot_assistance_dot_session__pb2
from avikom.assistance import session_query_pb2 as avikom_dot_assistance_dot_session__query__pb2
from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\'avikom/assistance/session_service.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/assistance_level.proto\x1a(avikom/assistance/instruction_text.proto\x1a)avikom/assistance/instruction_media.proto\x1a)avikom/assistance/runtime_step_list.proto\x1a\x1f\x61vikom/assistance/session.proto\x1a%avikom/assistance/session_query.proto\x1a\x1c\x61vikom/options/options.proto\x1a\x1d\x61vikom/generic/modality.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x19\x61vikom/generic/peer.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\"y\n\x1a\x45nvironmentalFactorsUpdate\x12\x12\n\nscene_name\x18\x01 \x01(\t\x12\x0f\n\x07user_id\x18\x02 \x01(\x04\x12\x12\n\nsession_id\x18\x03 \x01(\t\x12\x12\n\nbrightness\x18\x05 \x01(\x02\x12\x0e\n\x06volume\x18\x06 \x01(\x02\"\\\n\x0cSessionEvent\x12\x12\n\nsession_id\x18\x01 \x01(\t\x12\x12\n\nevent_name\x18\x02 \x01(\t\x12$\n\x06sender\x18\x03 \x01(\x0b\x32\x14.avikom.generic.Peer\",\n\tTaskEvent\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12\x0e\n\x06result\x18\x02 \x01(\t\"\x7f\n\x0fInstructionList\x12\x38\n\x0cinstructions\x18\x01 \x03(\x0b\x32\".avikom.assistance.InstructionText\x12\x32\n\x05media\x18\x02 \x03(\x0b\x32#.avikom.assistance.InstructionMedia2\xa2\x06\n\x0eSessionService\x12\x46\n\tEmitEvent\x12\x1f.avikom.assistance.SessionEvent\x1a\x16.avikom.generic.Result\"\x00\x12J\n\x10\x43ompleteTaskStep\x12\x1c.avikom.assistance.TaskEvent\x1a\x16.avikom.generic.Result\"\x00\x12\x46\n\x0c\x46\x61ilTaskStep\x12\x1c.avikom.assistance.TaskEvent\x1a\x16.avikom.generic.Result\"\x00\x12W\n\x0eGetCurrentStep\x12\x1f.avikom.assistance.SessionQuery\x1a\".avikom.assistance.RuntimeStepList\"\x00\x12I\n\x0cStartSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"\x00\x12K\n\x0eSuspendSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"\x00\x12G\n\nEndSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"\x00\x12\x65\n\x1aUpdateEnvironmentalFactors\x12-.avikom.assistance.EnvironmentalFactorsUpdate\x1a\x16.avikom.generic.Result\"\x00\x12N\n\x10RegisterUserPeer\x12\x14.avikom.generic.Peer\x1a\".avikom.assistance.RuntimeStepList\"\x00\x12\x43\n\x0f\x45ndAllProcesses\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ENVIRONMENTALFACTORSUPDATE._serialized_start=480
  _ENVIRONMENTALFACTORSUPDATE._serialized_end=601
  _SESSIONEVENT._serialized_start=603
  _SESSIONEVENT._serialized_end=695
  _TASKEVENT._serialized_start=697
  _TASKEVENT._serialized_end=741
  _INSTRUCTIONLIST._serialized_start=743
  _INSTRUCTIONLIST._serialized_end=870
  _SESSIONSERVICE._serialized_start=873
  _SESSIONSERVICE._serialized_end=1675
# @@protoc_insertion_point(module_scope)
