# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import runtime_task_step_pb2 as avikom_dot_assistance_dot_runtime__task__step__pb2
from avikom.camunda import external_task_pb2 as avikom_dot_camunda_dot_external__task__pb2
from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import user_profile_pb2 as avikom_dot_generic_dot_user__profile__pb2
from avikom.generic import modality_pb2 as avikom_dot_generic_dot_modality__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61vikom/assistance/session.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a)avikom/assistance/runtime_task_step.proto\x1a\"avikom/camunda/external_task.proto\x1a\x19\x61vikom/generic/peer.proto\x1a!avikom/generic/user_profile.proto\x1a\x1d\x61vikom/generic/modality.proto\"\xc0\x02\n\x07Session\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12\'\n\x05scene\x18\x02 \x01(\x0b\x32\x18.avikom.assistance.Scene\x12#\n\x05peers\x18\x03 \x03(\x0b\x32\x14.avikom.generic.Peer\x12\x33\n\x07\x63urrent\x18\x04 \x03(\x0b\x32\".avikom.assistance.RuntimeTaskStep\x12,\n\x07profile\x18\x05 \x01(\x0b\x32\x1b.avikom.generic.UserProfile\x12%\n\x04task\x18\x06 \x01(\x0b\x32\x17.avikom.assistance.Task\x12\x30\n\x0emodal_affinity\x18\x07 \x01(\x0b\x32\x18.avikom.generic.Modality\x12\x11\n\tjson_data\x18\n \x01(\t:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SESSION.fields_by_name['id']._options = None
  _SESSION.fields_by_name['id']._serialized_options = b'\212\265\030\002\020\001'
  _SESSION._options = None
  _SESSION._serialized_options = b'\210\265\030\001'
  _SESSION._serialized_start=318
  _SESSION._serialized_end=638
# @@protoc_insertion_point(module_scope)
