# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/media_info.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import content_type_pb2 as avikom_dot_generic_dot_content__type__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1f\x61vikom/glasses/media_info.proto\x12\x0e\x61vikom.glasses\x1a!avikom/generic/content_type.proto\"h\n\tMediaInfo\x12\x12\n\nmedia_name\x18\x01 \x01(\t\x12\x31\n\x0c\x63ontent_type\x18\x02 \x01(\x0e\x32\x1b.avikom.generic.ContentType\x12\x14\n\x0cmilliseconds\x18\x03 \x01(\rBl\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.media_info_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _MEDIAINFO._serialized_start=86
  _MEDIAINFO._serialized_end=190
# @@protoc_insertion_point(module_scope)
