# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/glasses/remote_control_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+avikom/glasses/remote_control_service.proto\x12\x0e\x61vikom.glasses\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/api/annotations.proto2\xf0\x04\n\x14RemoteControlService\x12\x43\n\x0fShowStepBrowser\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x43\n\x0fHideStepBrowser\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12@\n\x0cShowNextStep\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x44\n\x10ShowPreviousStep\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x41\n\rShowNextMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12\x45\n\x11ShowPreviousMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12=\n\tPlayMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12>\n\nPauseMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x12=\n\tStopMedia\x12\x16.google.protobuf.Empty\x1a\x16.avikom.generic.Result\"\x00\x42l\n\x18\x61pp.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\xaa\x02\x14\x41vikom.Types.Glassesb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.glasses.remote_control_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.glassesZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/glasses\252\002\024Avikom.Types.Glasses'
  _REMOTECONTROLSERVICE._serialized_start=152
  _REMOTECONTROLSERVICE._serialized_end=776
# @@protoc_insertion_point(module_scope)
