# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/user.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x19\x61vikom/generic/user.proto\x12\x0e\x61vikom.generic\x1a\x1c\x61vikom/options/options.proto\"Z\n\x04User\x12\x12\n\nfirst_name\x18\x01 \x01(\t\x12\x11\n\tlast_name\x18\x02 \x01(\t\x12\x12\n\x02id\x18\x03 \x01(\x04\x42\x06\x8a\xb5\x18\x02\x10\x01\x12\x11\n\tusernames\x18\x04 \x03(\t:\x04\x88\xb5\x18\x01\x42l\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.user_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _USER.fields_by_name['id']._options = None
  _USER.fields_by_name['id']._serialized_options = b'\212\265\030\002\020\001'
  _USER._options = None
  _USER._serialized_options = b'\210\265\030\001'
  _USER._serialized_start=75
  _USER._serialized_end=165
# @@protoc_insertion_point(module_scope)
