"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.runtime_step_state_pb2
import avikom.assistance.task_step_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RuntimeTaskStep(google.protobuf.message.Message):
    """*
    Adds runtime-specific (temporal) data to a (static) TaskStep
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEP_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    @property
    def step(self) -> avikom.assistance.task_step_pb2.TaskStep:
        """/ the task defintion; fields have been dynamically altered and contain context-specific values"""
    id: builtins.str
    """/ a unique key to define this particular RTS instance"""
    state: avikom.assistance.runtime_step_state_pb2.RuntimeStepState.ValueType
    """/ current state of the runtime task step"""
    def __init__(
        self,
        *,
        step: avikom.assistance.task_step_pb2.TaskStep | None = ...,
        id: builtins.str = ...,
        state: avikom.assistance.runtime_step_state_pb2.RuntimeStepState.ValueType = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["step", b"step"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "state", b"state", "step", b"step"]) -> None: ...

global___RuntimeTaskStep = RuntimeTaskStep
