# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/rpc_endpoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/generic/rpc_endpoint.proto\x12\x0e\x61vikom.generic*\xbc\x02\n\x0bRpcEndpoint\x12\x14\n\x10\x45NDPOINT_UNKNOWN\x10\x00\x12\x1b\n\x17\x45NDPOINT_SCENE_CONSUMER\x10\x01\x12\x1b\n\x17\x45NDPOINT_MEDIA_FOLLOWER\x10\x02\x12\x1b\n\x17\x45NDPOINT_REMOTE_CONTROL\x10\x03\x12\x1f\n\x1b\x45NDPOINT_AUDIO_PEER_CONTROL\x10\x04\x12\x11\n\rENDPOINT_GAZE\x10\x05\x12\x12\n\x0e\x45NDPOINT_IMAGE\x10\x06\x12\x15\n\x11\x45NDPOINT_LOCATION\x10\x07\x12\x1e\n\x1a\x45NDPOINT_INTERACTION_EVENT\x10\x08\x12\x1d\n\x19\x45NDPOINT_SERVICE_PROVIDER\x10\t\x12\"\n\x1e\x45NDPOINT_RUNTIME_STEP_CONSUMER\x10\nBl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.rpc_endpoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _RPCENDPOINT._serialized_start=54
  _RPCENDPOINT._serialized_end=370
# @@protoc_insertion_point(module_scope)
