# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/waypoint.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.math import vector3d_pb2 as avikom_dot_math_dot_vector3d__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1b\x61vikom/unity/waypoint.proto\x12\x0c\x61vikom.unity\x1a\x1a\x61vikom/math/vector3d.proto\"g\n\x08Waypoint\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\'\n\x08location\x18\x02 \x01(\x0b\x32\x15.avikom.math.Vector3D\x12\x11\n\tneighbors\x18\x03 \x03(\t\x12\x11\n\tthreshold\x18\x04 \x01(\x02\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.waypoint_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _WAYPOINT._serialized_start=73
  _WAYPOINT._serialized_end=176
# @@protoc_insertion_point(module_scope)
