# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/common_utterance.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/headset/common_utterance.proto\x12\x0e\x61vikom.headset*\x8b\x01\n\x0f\x43ommonUtterance\x12\x1c\n\x18\x43OMMON_UTTERANCE_DEFAULT\x10\x00\x12\x1b\n\x17\x43OMMON_UTTERANCE_REPEAT\x10\x01\x12\x1c\n\x18\x43OMMON_UTTERANCE_APPROVE\x10\x02\x12\x1f\n\x1b\x43OMMON_UTTERANCE_COMPLIMENT\x10\x03\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.common_utterance_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _COMMONUTTERANCE._serialized_start=58
  _COMMONUTTERANCE._serialized_end=197
# @@protoc_insertion_point(module_scope)
