# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/runtime_step_consumer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.assistance import runtime_step_list_pb2 as avikom_dot_assistance_dot_runtime__step__list__pb2
from avikom.assistance import runtime_step_state_pb2 as avikom_dot_assistance_dot_runtime__step__state__pb2
from avikom.assistance import runtime_step_state_change_pb2 as avikom_dot_assistance_dot_runtime__step__state__change__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5avikom/assistance/runtime_step_consumer_service.proto\x12\x11\x61vikom.assistance\x1a\x19\x61vikom/generic/peer.proto\x1a)avikom/assistance/runtime_step_list.proto\x1a*avikom/assistance/runtime_step_state.proto\x1a\x31\x61vikom/assistance/runtime_step_state_change.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto2\x87\x02\n\x1aRuntimeStepConsumerService\x12O\n\x0fSetRuntimeSteps\x12\".avikom.assistance.RuntimeStepList\x1a\x16.avikom.generic.Result\"\x00\x12X\n\x11UpdateRuntimeStep\x12).avikom.assistance.RuntimeStepStateChange\x1a\x16.google.protobuf.Empty\"\x00\x12>\n\x08SetPeers\x12\x18.avikom.generic.PeerList\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.runtime_step_consumer_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _RUNTIMESTEPCONSUMERSERVICE._serialized_start=300
  _RUNTIMESTEPCONSUMERSERVICE._serialized_end=563
# @@protoc_insertion_point(module_scope)
