"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.scene_pb2
import avikom.assistance.task_pb2
import avikom.assistance.task_step_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TaskStorageQuery(google.protobuf.message.Message):
    """*
    A query to retrieve a scene, task or task step via its name.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ name of a scene, task or task step"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___TaskStorageQuery = TaskStorageQuery

@typing_extensions.final
class SceneList(google.protobuf.message.Message):
    """*
    A list of scenes.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SCENES_FIELD_NUMBER: builtins.int
    @property
    def scenes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.scene_pb2.Scene]:
        """a scene list"""
    def __init__(
        self,
        *,
        scenes: collections.abc.Iterable[avikom.assistance.scene_pb2.Scene] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["scenes", b"scenes"]) -> None: ...

global___SceneList = SceneList

@typing_extensions.final
class TaskList(google.protobuf.message.Message):
    """*
    A list of tasks.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASKS_FIELD_NUMBER: builtins.int
    @property
    def tasks(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_pb2.Task]:
        """a task list"""
    def __init__(
        self,
        *,
        tasks: collections.abc.Iterable[avikom.assistance.task_pb2.Task] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["tasks", b"tasks"]) -> None: ...

global___TaskList = TaskList

@typing_extensions.final
class TaskStepList(google.protobuf.message.Message):
    """*
    A list of task steps.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STEPS_FIELD_NUMBER: builtins.int
    @property
    def steps(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.assistance.task_step_pb2.TaskStep]:
        """a task step list"""
    def __init__(
        self,
        *,
        steps: collections.abc.Iterable[avikom.assistance.task_step_pb2.TaskStep] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["steps", b"steps"]) -> None: ...

global___TaskStepList = TaskStepList
