"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssetBundleInfo(google.protobuf.message.Message):
    """*
    A message header to send Unity asset bundles in chunks.
    Should be available in every initial message to an asset bunde receiver.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIZE_FIELD_NUMBER: builtins.int
    CHUNK_SIZE_FIELD_NUMBER: builtins.int
    BUNDLE_NAME_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    size: builtins.int
    """/ size of the whole bundle in bytes"""
    chunk_size: builtins.int
    """/ the planed size of each data chunk"""
    bundle_name: builtins.str
    """/ globally unique name of the asset bundle in question"""
    version: builtins.str
    """/ version of the bundle to determine whether sending binary data is required or not"""
    def __init__(
        self,
        *,
        size: builtins.int = ...,
        chunk_size: builtins.int = ...,
        bundle_name: builtins.str = ...,
        version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bundle_name", b"bundle_name", "chunk_size", b"chunk_size", "size", b"size", "version", b"version"]) -> None: ...

global___AssetBundleInfo = AssetBundleInfo
