"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ContentType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ContentTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ContentType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    CONTENT_UNKNOWN: _ContentType.ValueType  # 0
    """/ no content type specified; should not be used actively"""
    CONTENT_IMAGE: _ContentType.ValueType  # 1
    """/ shows 2-D images"""
    CONTENT_VIDEO: _ContentType.ValueType  # 2
    """/ shows videos"""
    CONTENT_TEXT: _ContentType.ValueType  # 3
    """/ shows instructions in text form; is also used to generate speech output if ssml is not defined"""
    CONTENT_AUDIO: _ContentType.ValueType  # 4
    """/ plays audio (e.g. background music)"""
    CONTENT_VISUAL: _ContentType.ValueType  # 5
    """/ shows images or holograms situated in space"""
    CONTENT_EXTERNAL: _ContentType.ValueType  # 6
    """/ will be opened with the default OS application"""
    CONTENT_SSML: _ContentType.ValueType  # 7
    """/ is used for enhanced tts output"""

class ContentType(_ContentType, metaclass=_ContentTypeEnumTypeWrapper):
    """*
    Defines the type of an Instruction.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

CONTENT_UNKNOWN: ContentType.ValueType  # 0
"""/ no content type specified; should not be used actively"""
CONTENT_IMAGE: ContentType.ValueType  # 1
"""/ shows 2-D images"""
CONTENT_VIDEO: ContentType.ValueType  # 2
"""/ shows videos"""
CONTENT_TEXT: ContentType.ValueType  # 3
"""/ shows instructions in text form; is also used to generate speech output if ssml is not defined"""
CONTENT_AUDIO: ContentType.ValueType  # 4
"""/ plays audio (e.g. background music)"""
CONTENT_VISUAL: ContentType.ValueType  # 5
"""/ shows images or holograms situated in space"""
CONTENT_EXTERNAL: ContentType.ValueType  # 6
"""/ will be opened with the default OS application"""
CONTENT_SSML: ContentType.ValueType  # 7
"""/ is used for enhanced tts output"""
global___ContentType = ContentType
