"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.math.vector3d_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Waypoint(google.protobuf.message.Message):
    """*
    This describes a point in space and its conceptual neighbours.
    Waypoints are used to savely guide users from one location to another.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NEIGHBORS_FIELD_NUMBER: builtins.int
    THRESHOLD_FIELD_NUMBER: builtins.int
    name: builtins.str
    """/ waypoint name to be adressable"""
    @property
    def location(self) -> avikom.math.vector3d_pb2.Vector3D:
        """/ location of the waypoint in world coordinates"""
    @property
    def neighbors(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ neightbouring waypoints; if not set they might be derived from other waypoint neighbourhood relationships"""
    threshold: builtins.float
    """/ a 'bubble' (in meters) around a waypoint that determines when a waypoint is considered reached"""
    def __init__(
        self,
        *,
        name: builtins.str = ...,
        location: avikom.math.vector3d_pb2.Vector3D | None = ...,
        neighbors: collections.abc.Iterable[builtins.str] | None = ...,
        threshold: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["location", b"location"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["location", b"location", "name", b"name", "neighbors", b"neighbors", "threshold", b"threshold"]) -> None: ...

global___Waypoint = Waypoint
