# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/split_procedure_result.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.math import float_matrix_pb2 as avikom_dot_math_dot_float__matrix__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.avikom/assistance/split_procedure_result.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a\x19\x61vikom/generic/user.proto\x1a\x1e\x61vikom/math/float_matrix.proto\"\x91\x01\n\x14SplitProcedureResult\x12\"\n\x04user\x18\x01 \x01(\x0b\x32\x14.avikom.generic.User\x12%\n\x04task\x18\x02 \x01(\x0b\x32\x17.avikom.assistance.Task\x12(\n\x06matrix\x18\x03 \x01(\x0b\x32\x18.avikom.math.FloatMatrix:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.split_procedure_result_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SPLITPROCEDURERESULT._options = None
  _SPLITPROCEDURERESULT._serialized_options = b'\210\265\030\001'
  _SPLITPROCEDURERESULT._serialized_start=189
  _SPLITPROCEDURERESULT._serialized_end=334
# @@protoc_insertion_point(module_scope)
