# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/issue_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.assistance import issue_pb2 as avikom_dot_assistance_dot_issue__pb2
from avikom.assistance import issue_query_pb2 as avikom_dot_assistance_dot_issue__query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/assistance/issue_service.proto\x12\x11\x61vikom.assistance\x1a\x1b\x61vikom/generic/result.proto\x1a\x1d\x61vikom/assistance/issue.proto\x1a#avikom/assistance/issue_query.proto\x1a\x1cgoogle/api/annotations.proto2\xa0\x01\n\x0cIssueService\x12\x45\n\nStartIssue\x12\x1d.avikom.assistance.IssueQuery\x1a\x16.avikom.generic.Result\"\x00\x12I\n\x08GetIssue\x12\x1d.avikom.assistance.IssueQuery\x1a\x1c.avikom.assistance.IssueList\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.issue_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ISSUESERVICE._serialized_start=188
  _ISSUESERVICE._serialized_end=348
# @@protoc_insertion_point(module_scope)
