# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/runtime_step_state_change.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import runtime_step_state_pb2 as avikom_dot_assistance_dot_runtime__step__state__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n1avikom/assistance/runtime_step_state_change.proto\x12\x11\x61vikom.assistance\x1a*avikom/assistance/runtime_step_state.proto\"X\n\x16RuntimeStepStateChange\x12\n\n\x02id\x18\x01 \x01(\t\x12\x32\n\x05state\x18\x02 \x01(\x0e\x32#.avikom.assistance.RuntimeStepStateBu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.runtime_step_state_change_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _RUNTIMESTEPSTATECHANGE._serialized_start=116
  _RUNTIMESTEPSTATECHANGE._serialized_end=204
# @@protoc_insertion_point(module_scope)
