"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.generic.key_value_pair_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ServiceConfiguration(google.protobuf.message.Message):
    """*
    A message that combines peer topics and related service configurations meant for TaskStep definitions.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TOPIC_FIELD_NUMBER: builtins.int
    PARAMETERS_FIELD_NUMBER: builtins.int
    topic: builtins.str
    """/ topic related to this service"""
    @property
    def parameters(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.generic.key_value_pair_pb2.KeyValuePair]:
        """/ key-value pairs to configure the requested service"""
    def __init__(
        self,
        *,
        topic: builtins.str = ...,
        parameters: collections.abc.Iterable[avikom.generic.key_value_pair_pb2.KeyValuePair] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["parameters", b"parameters", "topic", b"topic"]) -> None: ...

global___ServiceConfiguration = ServiceConfiguration
