"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _ErrorCode:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ErrorCodeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_ErrorCode.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    NO_ERROR: _ErrorCode.ValueType  # 0
    """/ default value when no error occured or the error was not specified"""
    INTERNAL_ERROR: _ErrorCode.ValueType  # 1
    """/ errors on server side that cannot be solved by client"""
    ATTRIBUTE_ERROR: _ErrorCode.ValueType  # 2
    """/ errors with regard to the attributes of the request"""
    VALUE_ERROR: _ErrorCode.ValueType  # 3
    """/ one or more attribute values provided were not valid"""
    RUNTIME_ERROR: _ErrorCode.ValueType  # 4
    """/ the error occured unexpectedly during execution of program"""
    NOT_IMPLEMENTED_ERROR: _ErrorCode.ValueType  # 5
    """/ returned if service called is not implemented on server side"""

class ErrorCode(_ErrorCode, metaclass=_ErrorCodeEnumTypeWrapper): ...

NO_ERROR: ErrorCode.ValueType  # 0
"""/ default value when no error occured or the error was not specified"""
INTERNAL_ERROR: ErrorCode.ValueType  # 1
"""/ errors on server side that cannot be solved by client"""
ATTRIBUTE_ERROR: ErrorCode.ValueType  # 2
"""/ errors with regard to the attributes of the request"""
VALUE_ERROR: ErrorCode.ValueType  # 3
"""/ one or more attribute values provided were not valid"""
RUNTIME_ERROR: ErrorCode.ValueType  # 4
"""/ the error occured unexpectedly during execution of program"""
NOT_IMPLEMENTED_ERROR: ErrorCode.ValueType  # 5
"""/ returned if service called is not implemented on server side"""
global___ErrorCode = ErrorCode

@typing_extensions.final
class Result(google.protobuf.message.Message):
    """*
    A message to provide feedback about sucessful or failed remote procedure calls
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUCCESS_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    ERROR_FIELD_NUMBER: builtins.int
    success: builtins.bool
    """/ true if sucessful, false otherwise"""
    message: builtins.str
    """/ additional semantic information; specifying what went wrong or communicate results of successful operations"""
    error: global___ErrorCode.ValueType
    """/ specifies the type of error that occured; will only be set if success is false"""
    def __init__(
        self,
        *,
        success: builtins.bool = ...,
        message: builtins.str = ...,
        error: global___ErrorCode.ValueType = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["error", b"error", "message", b"message", "success", b"success"]) -> None: ...

global___Result = Result
