"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.glasses.interaction_type_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InteractionEvent(google.protobuf.message.Message):
    """*
    This message describes a user interaction with a virtual or real-world artifact.
    The kind and target of an interaction is communicated.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TYPE_FIELD_NUMBER: builtins.int
    TARGET_FIELD_NUMBER: builtins.int
    type: avikom.glasses.interaction_type_pb2.InteractionType.ValueType
    """/ type of interaction (e.g. click, touch, drag)"""
    target: builtins.str
    """/ the unique name of the targt object"""
    def __init__(
        self,
        *,
        type: avikom.glasses.interaction_type_pb2.InteractionType.ValueType = ...,
        target: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target", b"target", "type", b"type"]) -> None: ...

global___InteractionEvent = InteractionEvent
