# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/issue.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.generic import key_value_pair_pb2 as avikom_dot_generic_dot_key__value__pair__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61vikom/assistance/issue.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a\x1c\x61vikom/options/options.proto\x1a\x19\x61vikom/generic/user.proto\x1a#avikom/generic/key_value_pair.proto\"\xdc\x02\n\x05Issue\x12\x12\n\x02id\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12$\n\x06issuer\x18\x02 \x01(\x0b\x32\x14.avikom.generic.User\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\'\n\x05scene\x18\x04 \x01(\x0b\x32\x18.avikom.assistance.Scene\x12%\n\x04task\x18\x05 \x01(\x0b\x32\x17.avikom.assistance.Task\x12%\n\x07include\x18\x06 \x03(\x0b\x32\x14.avikom.generic.User\x12%\n\x07\x65xclude\x18\x07 \x03(\x0b\x32\x14.avikom.generic.User\x12\x30\n\nparameters\x18\x08 \x03(\x0b\x32\x1c.avikom.generic.KeyValuePair\x12.\n\x06status\x18\t \x01(\x0e\x32\x1e.avikom.assistance.IssueStatus:\x04\x88\xb5\x18\x01\"5\n\tIssueList\x12(\n\x06issues\x18\x01 \x03(\x0b\x32\x18.avikom.assistance.Issue*|\n\x0bIssueStatus\x12\x11\n\rISSUE_UNKNOWN\x10\x00\x12\x0e\n\nISSUE_OPEN\x10\x01\x12\x12\n\x0eISSUE_ASSIGNED\x10\x05\x12\x10\n\x0cISSUE_ACTIVE\x10\x07\x12\x10\n\x0cISSUE_CLOSED\x10\n\x12\x12\n\x0eISSUE_REJECTED\x10\x0b\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.issue_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ISSUE.fields_by_name['id']._options = None
  _ISSUE.fields_by_name['id']._serialized_options = b'\212\265\030\002\020\001'
  _ISSUE._options = None
  _ISSUE._serialized_options = b'\210\265\030\001'
  _ISSUESTATUS._serialized_start=613
  _ISSUESTATUS._serialized_end=737
  _ISSUE._serialized_start=208
  _ISSUE._serialized_end=556
  _ISSUELIST._serialized_start=558
  _ISSUELIST._serialized_end=611
# @@protoc_insertion_point(module_scope)
