"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.unity.game_object_pb2
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TaskConfig(google.protobuf.message.Message):
    """*
    This message describes a task config and contains context-specific objects.
    All assets should have a parent that represents their location within a scene.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TASK_NAME_FIELD_NUMBER: builtins.int
    ASSETS_FIELD_NUMBER: builtins.int
    task_name: builtins.str
    """/ name of the task that is configured"""
    @property
    def assets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[avikom.unity.game_object_pb2.GameObject]:
        """/ a list of assets that represent (virtual) task-specific assets"""
    def __init__(
        self,
        *,
        task_name: builtins.str = ...,
        assets: collections.abc.Iterable[avikom.unity.game_object_pb2.GameObject] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["assets", b"assets", "task_name", b"task_name"]) -> None: ...

global___TaskConfig = TaskConfig
