"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _Protocol:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _ProtocolEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_Protocol.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    PROTOCOL_TCP: _Protocol.ValueType  # 0
    PROTOCOL_WEBSOCKET: _Protocol.ValueType  # 1

class Protocol(_Protocol, metaclass=_ProtocolEnumTypeWrapper): ...

PROTOCOL_TCP: Protocol.ValueType  # 0
PROTOCOL_WEBSOCKET: Protocol.ValueType  # 1
global___Protocol = Protocol

class _VideoQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _VideoQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_VideoQuality.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    QUALITY_VIDEO_NONE: _VideoQuality.ValueType  # 0
    QUALITY_VIDEO_LOWEST: _VideoQuality.ValueType  # 1
    QUALITY_VIDEO_DEFAULT: _VideoQuality.ValueType  # 5
    QUALITY_VIDEO_HIGHEST: _VideoQuality.ValueType  # 10

class VideoQuality(_VideoQuality, metaclass=_VideoQualityEnumTypeWrapper): ...

QUALITY_VIDEO_NONE: VideoQuality.ValueType  # 0
QUALITY_VIDEO_LOWEST: VideoQuality.ValueType  # 1
QUALITY_VIDEO_DEFAULT: VideoQuality.ValueType  # 5
QUALITY_VIDEO_HIGHEST: VideoQuality.ValueType  # 10
global___VideoQuality = VideoQuality

class _AudioQuality:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AudioQualityEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AudioQuality.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    QUALITY_AUDIO_NONE: _AudioQuality.ValueType  # 0
    QUALITY_AUDIO_LOWEST: _AudioQuality.ValueType  # 1
    QUALITY_AUDIO_DEFAULT: _AudioQuality.ValueType  # 5
    QUALITY_AUDIO_HIGHEST: _AudioQuality.ValueType  # 10

class AudioQuality(_AudioQuality, metaclass=_AudioQualityEnumTypeWrapper): ...

QUALITY_AUDIO_NONE: AudioQuality.ValueType  # 0
QUALITY_AUDIO_LOWEST: AudioQuality.ValueType  # 1
QUALITY_AUDIO_DEFAULT: AudioQuality.ValueType  # 5
QUALITY_AUDIO_HIGHEST: AudioQuality.ValueType  # 10
global___AudioQuality = AudioQuality

@typing_extensions.final
class StreamRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PROTOCOL_FIELD_NUMBER: builtins.int
    AUDIO_QUALITY_FIELD_NUMBER: builtins.int
    VIDEO_QUALITY_FIELD_NUMBER: builtins.int
    SEND_AUGMENTED_FIELD_NUMBER: builtins.int
    RECEIVE_AUDIO_FIELD_NUMBER: builtins.int
    RECEIVE_VIDEO_FIELD_NUMBER: builtins.int
    protocol: global___Protocol.ValueType
    audio_quality: global___AudioQuality.ValueType
    video_quality: global___VideoQuality.ValueType
    send_augmented: builtins.bool
    receive_audio: builtins.bool
    receive_video: builtins.bool
    def __init__(
        self,
        *,
        protocol: global___Protocol.ValueType = ...,
        audio_quality: global___AudioQuality.ValueType = ...,
        video_quality: global___VideoQuality.ValueType = ...,
        send_augmented: builtins.bool = ...,
        receive_audio: builtins.bool = ...,
        receive_video: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["audio_quality", b"audio_quality", "protocol", b"protocol", "receive_audio", b"receive_audio", "receive_video", b"receive_video", "send_augmented", b"send_augmented", "video_quality", b"video_quality"]) -> None: ...

global___StreamRequest = StreamRequest
