# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tracking/location_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.math import vector3d_pb2 as avikom_dot_math_dot_vector3d__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&avikom/tracking/location_service.proto\x12\x0f\x61vikom.tracking\x1a\x1a\x61vikom/math/vector3d.proto\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1bgoogle/protobuf/empty.proto\"B\n\rTargetRequest\x12\x0e\n\x06target\x18\x01 \x01(\t\x12\x10\n\x08sleep_ms\x18\x02 \x01(\x05\x12\x0f\n\x07watcher\x18\x03 \x01(\t2\xb2\x01\n\x0fLocationService\x12M\n\x10GetScenePosition\x12\x1e.avikom.tracking.TargetRequest\x1a\x15.avikom.math.Vector3D\"\x00\x30\x01\x12P\n\x13GetRelativePosition\x12\x1e.avikom.tracking.TargetRequest\x1a\x15.avikom.math.Vector3D\"\x00\x30\x01\x42o\n\x19\x61pp.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\xaa\x02\x15\x41vikom.Types.Trackingb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tracking.location_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\031app.avikom.types.trackingZ:gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tracking\252\002\025Avikom.Types.Tracking'
  _TARGETREQUEST._serialized_start=148
  _TARGETREQUEST._serialized_end=214
  _LOCATIONSERVICE._serialized_start=217
  _LOCATIONSERVICE._serialized_end=395
# @@protoc_insertion_point(module_scope)
