# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_media_value.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/assistance/instruction_media_value.proto\x12\x11\x61vikom.assistance\"\x8d\x01\n\x15InstructionMediaValue\x12\x0b\n\x03uri\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x03 \x01(\x0c\x12*\n\x04type\x18\x04 \x01(\x0e\x32\x1c.avikom.assistance.MediaType\x12\x0e\n\x06looped\x18\n \x01(\x08\x12\x10\n\x08\x61utoplay\x18\x0b \x01(\x08*\xe2\x01\n\tMediaType\x12\x10\n\x0cTYPE_UNKNOWN\x10\x00\x12\x13\n\x0fTYPE_IMAGE_JPEG\x10\x01\x12\x12\n\x0eTYPE_IMAGE_PNG\x10\x02\x12\x12\n\x0eTYPE_VIDEO_MP4\x10\x05\x12\x12\n\x0eTYPE_AUDIO_WAV\x10\n\x12\x12\n\x0eTYPE_AUDIO_MP3\x10\x0b\x12\x18\n\x14TYPE_APPLICATION_PDF\x10\x14\x12\x18\n\x14TYPE_APPLICATION_XML\x10\x15\x12\x13\n\x0fTYPE_TEXT_PLAIN\x10\x1e\x12\x15\n\x11TYPE_WORLD_OBJECT\x10(Bu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_media_value_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _MEDIATYPE._serialized_start=215
  _MEDIATYPE._serialized_end=441
  _INSTRUCTIONMEDIAVALUE._serialized_start=71
  _INSTRUCTIONMEDIAVALUE._serialized_end=212
# @@protoc_insertion_point(module_scope)
