# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/functional_sound.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%avikom/headset/functional_sound.proto\x12\x0e\x61vikom.headset*\x85\x03\n\x0f\x46unctionalSound\x12\x11\n\rSOUND_DEFAULT\x10\x00\x12\x12\n\x0eSOUND_GUIDANCE\x10\x01\x12\x1a\n\x16SOUND_INSTRUCTION_INFO\x10\x02\x12\x1b\n\x17SOUND_INSTRUCTION_ALERT\x10\x03\x12\x1b\n\x17SOUND_INSTRUCTION_ALARM\x10\x04\x12\x0f\n\x0bSOUND_ERROR\x10\x05\x12\x18\n\x14SOUND_TASK_COMPLETED\x10\x06\x12\x1e\n\x1aSOUND_SYSTEM_PROGRESS_WAIT\x10\x07\x12\x1e\n\x1aSOUND_NEXT_STEP_IN_BROWSER\x10\x08\x12\"\n\x1eSOUND_PREVIOUS_STEP_IN_BROWSER\x10\t\x12\x15\n\x11SOUND_BUTTON_DOWN\x10\n\x12\x13\n\x0fSOUND_BUTTON_UP\x10\x0b\x12\r\n\tSOUND_TAP\x10\x0c\x12\x15\n\x11SOUND_GRASP_START\x10\r\x12\x14\n\x10SOUND_GRASP_STOP\x10\x0e\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.functional_sound_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _FUNCTIONALSOUND._serialized_start=58
  _FUNCTIONALSOUND._serialized_end=447
# @@protoc_insertion_point(module_scope)
