# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/instruction_text.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import instruction_meta_pb2 as avikom_dot_assistance_dot_instruction__meta__pb2
from avikom.assistance import instruction_text_value_pb2 as avikom_dot_assistance_dot_instruction__text__value__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/instruction_text.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/instruction_meta.proto\x1a.avikom/assistance/instruction_text_value.proto\"\xef\x01\n\x0fInstructionText\x12\x30\n\x04meta\x18\x01 \x01(\x0b\x32\".avikom.assistance.InstructionMeta\x12\x36\n\rcontent_style\x18\n \x01(\x0e\x32\x1f.avikom.assistance.ContentStyle\x12\x38\n\x07\x63ontent\x18\x0b \x01(\x0b\x32\'.avikom.assistance.InstructionTextValue\x12\x38\n\x07preview\x18\x0c \x01(\x0b\x32\'.avikom.assistance.InstructionTextValue*{\n\x0c\x43ontentStyle\x12\x11\n\rSTYLE_UNKNOWN\x10\x00\x12\x0e\n\nSTYLE_INFO\x10\x01\x12\x11\n\rSTYLE_WARNING\x10\x02\x12\x12\n\x0eSTYLE_CRITICAL\x10\x03\x12\x10\n\x0cSTYLE_SUCESS\x10\x04\x12\x0f\n\x0bSTYLE_ERROR\x10\x05\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.instruction_text_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _CONTENTSTYLE._serialized_start=395
  _CONTENTSTYLE._serialized_end=518
  _INSTRUCTIONTEXT._serialized_start=154
  _INSTRUCTIONTEXT._serialized_end=393
# @@protoc_insertion_point(module_scope)
