# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/game_object_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&avikom/unity/game_object_service.proto\x12\x0c\x61vikom.unity\x1a\x1b\x61vikom/generic/result.proto\x1a\x1e\x61vikom/unity/game_object.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1f\x61vikom/unity/asset_bundle.proto\"\x1f\n\x0fGameObjectQuery\x12\x0c\n\x04name\x18\x01 \x01(\t2\xf4\x02\n\x11GameObjectService\x12W\n\x03\x41\x64\x64\x12\x18.avikom.unity.GameObject\x1a\x16.avikom.generic.Result\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/v1/glasses/objects:\x01*\x12^\n\x03Set\x12\x18.avikom.unity.GameObject\x1a\x16.avikom.generic.Result\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/v1/glasses/objects/{name}:\x01*\x12\x62\n\x03Get\x12\x1d.avikom.unity.GameObjectQuery\x1a\x18.avikom.unity.GameObject\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/v1/glasses/objects/{name}\x12\x42\n\tAddBundle\x12\x19.avikom.unity.AssetBundle\x1a\x16.avikom.generic.Result\"\x00(\x01\x42\x66\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.game_object_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _GAMEOBJECTSERVICE.methods_by_name['Add']._options = None
  _GAMEOBJECTSERVICE.methods_by_name['Add']._serialized_options = b'\202\323\344\223\002\030\"\023/v1/glasses/objects:\001*'
  _GAMEOBJECTSERVICE.methods_by_name['Set']._options = None
  _GAMEOBJECTSERVICE.methods_by_name['Set']._serialized_options = b'\202\323\344\223\002\037\"\032/v1/glasses/objects/{name}:\001*'
  _GAMEOBJECTSERVICE.methods_by_name['Get']._options = None
  _GAMEOBJECTSERVICE.methods_by_name['Get']._serialized_options = b'\202\323\344\223\002\034\022\032/v1/glasses/objects/{name}'
  _GAMEOBJECTQUERY._serialized_start=180
  _GAMEOBJECTQUERY._serialized_end=211
  _GAMEOBJECTSERVICE._serialized_start=214
  _GAMEOBJECTSERVICE._serialized_end=586
# @@protoc_insertion_point(module_scope)
