# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/headset/rasa_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.headset import rasa_message_pb2 as avikom_dot_headset_dot_rasa__message__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n!avikom/headset/rasa_service.proto\x12\x0e\x61vikom.headset\x1a!avikom/headset/rasa_message.proto\x1a\x1b\x61vikom/generic/result.proto\"\x1c\n\tRasaQuery\x12\x0f\n\x07user_id\x18\x01 \x01(\x04\"\x1d\n\nRasaResult\x12\x0f\n\x07intents\x18\x01 \x03(\t2\x98\x01\n\x0bRasaService\x12\x42\n\tSetIntent\x12\x1b.avikom.headset.RasaMessage\x1a\x16.avikom.generic.Result\"\x00\x12\x45\n\nGetIntents\x12\x19.avikom.headset.RasaQuery\x1a\x1a.avikom.headset.RasaResult\"\x00\x42l\n\x18\x61pp.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\xaa\x02\x14\x41vikom.Types.Headsetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.headset.rasa_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.headsetZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/headset\252\002\024Avikom.Types.Headset'
  _RASAQUERY._serialized_start=117
  _RASAQUERY._serialized_end=145
  _RASARESULT._serialized_start=147
  _RASARESULT._serialized_end=176
  _RASASERVICE._serialized_start=179
  _RASASERVICE._serialized_end=331
# @@protoc_insertion_point(module_scope)
