"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InstructionTextValue(google.protobuf.message.Message):
    """*
    The actual value of a text instruction in different representations
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PLAIN_FIELD_NUMBER: builtins.int
    SSML_FIELD_NUMBER: builtins.int
    HTML_FIELD_NUMBER: builtins.int
    plain: builtins.str
    """/ value as plain text"""
    ssml: builtins.str
    """/ value with Speech Synthesis Markup Language annotation"""
    html: builtins.str
    """/ value with HTML annotation"""
    def __init__(
        self,
        *,
        plain: builtins.str = ...,
        ssml: builtins.str = ...,
        html: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["html", b"html", "plain", b"plain", "ssml", b"ssml"]) -> None: ...

global___InstructionTextValue = InstructionTextValue
