"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ChoiceItem(google.protobuf.message.Message):
    """*
    This message represents a choice a user can select. It is commonly part of a selection of choices 
    in a ChoiceConfig.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VALUE_FIELD_NUMBER: builtins.int
    LABEL_FIELD_NUMBER: builtins.int
    SELECTED_FIELD_NUMBER: builtins.int
    DISABLED_FIELD_NUMBER: builtins.int
    value: builtins.str
    """/ The value a peer should return when a user made a choice."""
    label: builtins.str
    """/ If set, present this (human readable) label instead of the actual choice value to the user."""
    selected: builtins.bool
    """/ Represents the current selection state of the item."""
    disabled: builtins.bool
    """/ Whether this item can currently be selected or not. Note that `true` also means an item cannot be deselected."""
    def __init__(
        self,
        *,
        value: builtins.str = ...,
        label: builtins.str = ...,
        selected: builtins.bool = ...,
        disabled: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["disabled", b"disabled", "label", b"label", "selected", b"selected", "value", b"value"]) -> None: ...

global___ChoiceItem = ChoiceItem
