"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.assistance.instruction_media_value_pb2
import avikom.assistance.instruction_meta_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class InstructionMedia(google.protobuf.message.Message):
    """*
    This message describes a media instruction. This includes the instruction's (MIME) type and either an URI or the media as a binary stream.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    META_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    PREVIEW_FIELD_NUMBER: builtins.int
    @property
    def meta(self) -> avikom.assistance.instruction_meta_pb2.InstructionMeta: ...
    @property
    def content(self) -> avikom.assistance.instruction_media_value_pb2.InstructionMediaValue: ...
    @property
    def preview(self) -> avikom.assistance.instruction_media_value_pb2.InstructionMediaValue: ...
    def __init__(
        self,
        *,
        meta: avikom.assistance.instruction_meta_pb2.InstructionMeta | None = ...,
        content: avikom.assistance.instruction_media_value_pb2.InstructionMediaValue | None = ...,
        preview: avikom.assistance.instruction_media_value_pb2.InstructionMediaValue | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["content", b"content", "meta", b"meta", "preview", b"preview"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "meta", b"meta", "preview", b"preview"]) -> None: ...

global___InstructionMedia = InstructionMedia
