# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tunnel/message_tunnel_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.tunnel import server_to_client_pb2 as avikom_dot_tunnel_dot_server__to__client__pb2
from avikom.tunnel import client_to_server_pb2 as avikom_dot_tunnel_dot_client__to__server__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*avikom/tunnel/message_tunnel_service.proto\x12\ravikom.tunnel\x1a$avikom/tunnel/server_to_client.proto\x1a$avikom/tunnel/client_to_server.proto2n\n\x14MessageTunnelService\x12V\n\x10RegisterTunneled\x12\x1d.avikom.tunnel.ClientToServer\x1a\x1d.avikom.tunnel.ServerToClient\"\x00(\x01\x30\x01\x42i\n\x17\x61pp.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\xaa\x02\x13\x41vikom.Types.Tunnelb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tunnel.message_tunnel_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\252\002\023Avikom.Types.Tunnel'
  _MESSAGETUNNELSERVICE._serialized_start=137
  _MESSAGETUNNELSERVICE._serialized_end=247
# @@protoc_insertion_point(module_scope)
