"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _FunctionalSound:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _FunctionalSoundEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_FunctionalSound.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    SOUND_DEFAULT: _FunctionalSound.ValueType  # 0
    """/ generates no output"""
    SOUND_GUIDANCE: _FunctionalSound.ValueType  # 1
    """/ should be used when trying to guide the user to specific location"""
    SOUND_INSTRUCTION_INFO: _FunctionalSound.ValueType  # 2
    """/ should be used for instructions with ContentStyle "INFO" """
    SOUND_INSTRUCTION_ALERT: _FunctionalSound.ValueType  # 3
    """/ should be used for instructions with ContentStyle "WARNING" """
    SOUND_INSTRUCTION_ALARM: _FunctionalSound.ValueType  # 4
    """/ should be used for instructions with ContentStyle "CRITICAL" """
    SOUND_ERROR: _FunctionalSound.ValueType  # 5
    """/ should be used when notifying a user that an error occured"""
    SOUND_TASK_COMPLETED: _FunctionalSound.ValueType  # 6
    """/ should be used for providing positive feedback in key moments (i.e. on completion of a task)"""
    SOUND_SYSTEM_PROGRESS_WAIT: _FunctionalSound.ValueType  # 7
    """/ should be used to notify user that the system is processing user input"""
    SOUND_NEXT_STEP_IN_BROWSER: _FunctionalSound.ValueType  # 8
    """/ should be used when next step is shown in step browser"""
    SOUND_PREVIOUS_STEP_IN_BROWSER: _FunctionalSound.ValueType  # 9
    """/ should be used when previous step is shown in step browser"""
    SOUND_BUTTON_DOWN: _FunctionalSound.ValueType  # 10
    """/ should be used when user presses a button"""
    SOUND_BUTTON_UP: _FunctionalSound.ValueType  # 11
    """/ shuold be used when user lifts button press"""
    SOUND_TAP: _FunctionalSound.ValueType  # 12
    """/ should be used when user taps"""
    SOUND_GRASP_START: _FunctionalSound.ValueType  # 13
    """/ should be used when user grasps a virtual object"""
    SOUND_GRASP_STOP: _FunctionalSound.ValueType  # 14
    """/ should be used when user releases a a virtual object"""

class FunctionalSound(_FunctionalSound, metaclass=_FunctionalSoundEnumTypeWrapper):
    """*
    This enum describes common functional sounds that can be played back on an auditory peer
    to provide feedback to a user.
    @author: Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

SOUND_DEFAULT: FunctionalSound.ValueType  # 0
"""/ generates no output"""
SOUND_GUIDANCE: FunctionalSound.ValueType  # 1
"""/ should be used when trying to guide the user to specific location"""
SOUND_INSTRUCTION_INFO: FunctionalSound.ValueType  # 2
"""/ should be used for instructions with ContentStyle "INFO" """
SOUND_INSTRUCTION_ALERT: FunctionalSound.ValueType  # 3
"""/ should be used for instructions with ContentStyle "WARNING" """
SOUND_INSTRUCTION_ALARM: FunctionalSound.ValueType  # 4
"""/ should be used for instructions with ContentStyle "CRITICAL" """
SOUND_ERROR: FunctionalSound.ValueType  # 5
"""/ should be used when notifying a user that an error occured"""
SOUND_TASK_COMPLETED: FunctionalSound.ValueType  # 6
"""/ should be used for providing positive feedback in key moments (i.e. on completion of a task)"""
SOUND_SYSTEM_PROGRESS_WAIT: FunctionalSound.ValueType  # 7
"""/ should be used to notify user that the system is processing user input"""
SOUND_NEXT_STEP_IN_BROWSER: FunctionalSound.ValueType  # 8
"""/ should be used when next step is shown in step browser"""
SOUND_PREVIOUS_STEP_IN_BROWSER: FunctionalSound.ValueType  # 9
"""/ should be used when previous step is shown in step browser"""
SOUND_BUTTON_DOWN: FunctionalSound.ValueType  # 10
"""/ should be used when user presses a button"""
SOUND_BUTTON_UP: FunctionalSound.ValueType  # 11
"""/ shuold be used when user lifts button press"""
SOUND_TAP: FunctionalSound.ValueType  # 12
"""/ should be used when user taps"""
SOUND_GRASP_START: FunctionalSound.ValueType  # 13
"""/ should be used when user grasps a virtual object"""
SOUND_GRASP_STOP: FunctionalSound.ValueType  # 14
"""/ should be used when user releases a a virtual object"""
global___FunctionalSound = FunctionalSound
