# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/vision/camera_state.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n avikom/vision/camera_state.proto\x12\ravikom.vision*L\n\x0b\x43\x61meraState\x12\x0f\n\x0bUNALLOCATED\x10\x00\x12\x0b\n\x07VUFORIA\x10\x01\x12\x0b\n\x07WEB_RTC\x10\x02\x12\x12\n\x0eSPECTATOR_VIEW\x10\x03*b\n\rCameraTrigger\x12\x0b\n\x07RELEASE\x10\x00\x12\x13\n\x0f\x41\x43QUIRE_VUFORIA\x10\x01\x12\x13\n\x0f\x41\x43QUIRE_WEB_RTC\x10\x02\x12\x1a\n\x16\x41\x43QUIRE_SPECTATOR_VIEW\x10\x03\x42i\n\x17\x61pp.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\xaa\x02\x13\x41vikom.Types.Visionb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.vision.camera_state_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.visionZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/vision\252\002\023Avikom.Types.Vision'
  _CAMERASTATE._serialized_start=51
  _CAMERASTATE._serialized_end=127
  _CAMERATRIGGER._serialized_start=129
  _CAMERATRIGGER._serialized_end=227
# @@protoc_insertion_point(module_scope)
