"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RpcEndpoint:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RpcEndpointEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RpcEndpoint.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    ENDPOINT_UNKNOWN: _RpcEndpoint.ValueType  # 0
    """/ default; should not be used actively"""
    ENDPOINT_SCENE_CONSUMER: _RpcEndpoint.ValueType  # 1
    """/ peer implements SceneConsumerService"""
    ENDPOINT_MEDIA_FOLLOWER: _RpcEndpoint.ValueType  # 2
    """/ peer implements MediaFollowerService"""
    ENDPOINT_REMOTE_CONTROL: _RpcEndpoint.ValueType  # 3
    """/ peer implements RemoteControlService"""
    ENDPOINT_AUDIO_PEER_CONTROL: _RpcEndpoint.ValueType  # 4
    """/ peer implements AudioPeerControlService"""
    ENDPOINT_GAZE: _RpcEndpoint.ValueType  # 5
    """/ peer implements GazeService"""
    ENDPOINT_IMAGE: _RpcEndpoint.ValueType  # 6
    """/ peer implements ImageService"""
    ENDPOINT_LOCATION: _RpcEndpoint.ValueType  # 7
    """/ provides relative position of an object to a target object; peer implements LocationService"""
    ENDPOINT_INTERACTION_EVENT: _RpcEndpoint.ValueType  # 8
    """/ peer implements InteractionEventService"""
    ENDPOINT_SERVICE_PROVIDER: _RpcEndpoint.ValueType  # 9
    """/ peer implements ServiceProviderService"""
    ENDPOINT_RUNTIME_STEP_CONSUMER: _RpcEndpoint.ValueType  # 10
    """/ peer implements RuntimeStepConsumerService"""

class RpcEndpoint(_RpcEndpoint, metaclass=_RpcEndpointEnumTypeWrapper):
    """*
    Indicates the RPC endpoints a peer implements/provides.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

ENDPOINT_UNKNOWN: RpcEndpoint.ValueType  # 0
"""/ default; should not be used actively"""
ENDPOINT_SCENE_CONSUMER: RpcEndpoint.ValueType  # 1
"""/ peer implements SceneConsumerService"""
ENDPOINT_MEDIA_FOLLOWER: RpcEndpoint.ValueType  # 2
"""/ peer implements MediaFollowerService"""
ENDPOINT_REMOTE_CONTROL: RpcEndpoint.ValueType  # 3
"""/ peer implements RemoteControlService"""
ENDPOINT_AUDIO_PEER_CONTROL: RpcEndpoint.ValueType  # 4
"""/ peer implements AudioPeerControlService"""
ENDPOINT_GAZE: RpcEndpoint.ValueType  # 5
"""/ peer implements GazeService"""
ENDPOINT_IMAGE: RpcEndpoint.ValueType  # 6
"""/ peer implements ImageService"""
ENDPOINT_LOCATION: RpcEndpoint.ValueType  # 7
"""/ provides relative position of an object to a target object; peer implements LocationService"""
ENDPOINT_INTERACTION_EVENT: RpcEndpoint.ValueType  # 8
"""/ peer implements InteractionEventService"""
ENDPOINT_SERVICE_PROVIDER: RpcEndpoint.ValueType  # 9
"""/ peer implements ServiceProviderService"""
ENDPOINT_RUNTIME_STEP_CONSUMER: RpcEndpoint.ValueType  # 10
"""/ peer implements RuntimeStepConsumerService"""
global___RpcEndpoint = RpcEndpoint
