# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/unity/game_object.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.unity import transpose_pb2 as avikom_dot_unity_dot_transpose__pb2
from avikom.unity import asset_bundle_pb2 as avikom_dot_unity_dot_asset__bundle__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1e\x61vikom/unity/game_object.proto\x12\x0c\x61vikom.unity\x1a\x1c\x61vikom/unity/transpose.proto\x1a\x1f\x61vikom/unity/asset_bundle.proto\"\x92\x01\n\nGameObject\x12\x0c\n\x04name\x18\x01 \x01(\t\x12*\n\ttranspose\x18\x02 \x01(\x0b\x32\x17.avikom.unity.Transpose\x12\x0e\n\x06prefab\x18\x03 \x01(\t\x12\x0e\n\x06parent\x18\x04 \x01(\t\x12*\n\x08\x63hildren\x18\x05 \x03(\x0b\x32\x18.avikom.unity.GameObjectBf\n\x16\x61pp.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\xaa\x02\x12\x41vikom.Types.Unityb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.unity.game_object_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\026app.avikom.types.unityZ7gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/unity\252\002\022Avikom.Types.Unity'
  _GAMEOBJECT._serialized_start=112
  _GAMEOBJECT._serialized_end=258
# @@protoc_insertion_point(module_scope)
