# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/step_proficiency_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import step_proficiency_pb2 as avikom_dot_assistance_dot_step__proficiency__pb2
from avikom.assistance import split_procedure_result_pb2 as avikom_dot_assistance_dot_split__procedure__result__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8avikom/assistance/step_proficiency_storage_service.proto\x12\x11\x61vikom.assistance\x1a(avikom/assistance/step_proficiency.proto\x1a.avikom/assistance/split_procedure_result.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1cgoogle/api/annotations.proto\"<\n\x14StepProficiencyQuery\x12\x0f\n\x07user_id\x18\x01 \x01(\r\x12\x13\n\x0btarget_name\x18\x02 \x01(\t2\xf5\x04\n\x1dStepProficiencyStorageService\x12\xa6\x01\n\x12GetStepProficiency\x12\'.avikom.assistance.StepProficiencyQuery\x1a\".avikom.assistance.StepProficiency\"C\x82\xd3\xe4\x93\x02=\x12;/v1/storage/step_proficiencies/step/{target_name}/{user_id}\x12{\n\x12SetStepProficiency\x12\".avikom.assistance.StepProficiency\x1a\x16.avikom.generic.Result\")\x82\xd3\xe4\x93\x02#\"\x1e/v1/storage/step_proficiencies:\x01*\x12\xa8\x01\n\x17GetSplitProcedureResult\x12\'.avikom.assistance.StepProficiencyQuery\x1a\'.avikom.assistance.SplitProcedureResult\";\x82\xd3\xe4\x93\x02\x35\x12\x33/v1/storage/split_procedure/{target_name}/{user_id}\x12\x82\x01\n\x17SetSplitProcedureResult\x12\'.avikom.assistance.SplitProcedureResult\x1a\x16.avikom.generic.Result\"&\x82\xd3\xe4\x93\x02 \"\x1b/v1/storage/split_procedure:\x01*Bu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.step_proficiency_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetStepProficiency']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetStepProficiency']._serialized_options = b'\202\323\344\223\002=\022;/v1/storage/step_proficiencies/step/{target_name}/{user_id}'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetStepProficiency']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetStepProficiency']._serialized_options = b'\202\323\344\223\002#\"\036/v1/storage/step_proficiencies:\001*'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetSplitProcedureResult']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['GetSplitProcedureResult']._serialized_options = b'\202\323\344\223\0025\0223/v1/storage/split_procedure/{target_name}/{user_id}'
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetSplitProcedureResult']._options = None
  _STEPPROFICIENCYSTORAGESERVICE.methods_by_name['SetSplitProcedureResult']._serialized_options = b'\202\323\344\223\002 \"\033/v1/storage/split_procedure:\001*'
  _STEPPROFICIENCYQUERY._serialized_start=228
  _STEPPROFICIENCYQUERY._serialized_end=288
  _STEPPROFICIENCYSTORAGESERVICE._serialized_start=291
  _STEPPROFICIENCYSTORAGESERVICE._serialized_end=920
# @@protoc_insertion_point(module_scope)
