"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _RuntimeStepState:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _RuntimeStepStateEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_RuntimeStepState.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    STATE_UNKNOWN: _RuntimeStepState.ValueType  # 0
    """/ default; might be treated as an error; should not be set explicitely"""
    STATE_CREATED: _RuntimeStepState.ValueType  # 1
    """/ An RTS has been created. This is usually not communicated to peers/consumers."""
    STATE_PENDING: _RuntimeStepState.ValueType  # 5
    """/ The task has been communicated to consumers and now needs to be resolved."""
    STATE_COMPLETED: _RuntimeStepState.ValueType  # 10
    """/ RTS has been completeted successfully"""
    STATE_FINAL: _RuntimeStepState.ValueType  # 11
    """/ RTS process ended with this step"""
    STATE_FAILED: _RuntimeStepState.ValueType  # 15
    """/ RTS processing failed"""
    STATE_CANCELLED: _RuntimeStepState.ValueType  # 20
    """/ RTS became invalid and has been cancelled"""
    STATE_ERROR: _RuntimeStepState.ValueType  # 25
    """/ An error that is not a cause of process- or consumer-related issues."""

class RuntimeStepState(_RuntimeStepState, metaclass=_RuntimeStepStateEnumTypeWrapper):
    """*
    A step state resembled an `IssueState` in many cases but is more detailed.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

STATE_UNKNOWN: RuntimeStepState.ValueType  # 0
"""/ default; might be treated as an error; should not be set explicitely"""
STATE_CREATED: RuntimeStepState.ValueType  # 1
"""/ An RTS has been created. This is usually not communicated to peers/consumers."""
STATE_PENDING: RuntimeStepState.ValueType  # 5
"""/ The task has been communicated to consumers and now needs to be resolved."""
STATE_COMPLETED: RuntimeStepState.ValueType  # 10
"""/ RTS has been completeted successfully"""
STATE_FINAL: RuntimeStepState.ValueType  # 11
"""/ RTS process ended with this step"""
STATE_FAILED: RuntimeStepState.ValueType  # 15
"""/ RTS processing failed"""
STATE_CANCELLED: RuntimeStepState.ValueType  # 20
"""/ RTS became invalid and has been cancelled"""
STATE_ERROR: RuntimeStepState.ValueType  # 25
"""/ An error that is not a cause of process- or consumer-related issues."""
global___RuntimeStepState = RuntimeStepState
