# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/service_provider_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.assistance import service_configuration_pb2 as avikom_dot_assistance_dot_service__configuration__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0avikom/assistance/service_provider_service.proto\x12\x11\x61vikom.assistance\x1a\x19\x61vikom/generic/peer.proto\x1a\x1b\x61vikom/generic/result.proto\x1a-avikom/assistance/service_configuration.proto\"\x86\x01\n\x0eServiceRequest\x12\x0f\n\x07task_id\x18\x01 \x01(\t\x12>\n\rconfiguration\x18\x02 \x01(\x0b\x32\'.avikom.assistance.ServiceConfiguration\x12#\n\x05peers\x18\x03 \x03(\x0b\x32\x14.avikom.generic.Peer2\xc0\x01\n\x16ServiceProviderService\x12Q\n\x12PostServiceRequest\x12!.avikom.assistance.ServiceRequest\x1a\x16.avikom.generic.Result\"\x00\x12S\n\x14\x43\x61ncelServiceRequest\x12!.avikom.assistance.ServiceRequest\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.service_provider_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SERVICEREQUEST._serialized_start=175
  _SERVICEREQUEST._serialized_end=309
  _SERVICEPROVIDERSERVICE._serialized_start=312
  _SERVICEPROVIDERSERVICE._serialized_end=504
# @@protoc_insertion_point(module_scope)
