# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/tunnel/client_to_server.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n$avikom/tunnel/client_to_server.proto\x12\ravikom.tunnel\x1a\x19\x61vikom/generic/peer.proto\"Z\n\x0e\x43lientToServer\x12\x10\n\x08response\x18\x01 \x01(\x0c\x12\x12\n\nmessage_id\x18\x02 \x01(\x04\x12\"\n\x04peer\x18\x03 \x01(\x0b\x32\x14.avikom.generic.PeerBi\n\x17\x61pp.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\xaa\x02\x13\x41vikom.Types.Tunnelb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.tunnel.client_to_server_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\027app.avikom.types.tunnelZ8gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/tunnel\252\002\023Avikom.Types.Tunnel'
  _CLIENTTOSERVER._serialized_start=82
  _CLIENTTOSERVER._serialized_end=172
# @@protoc_insertion_point(module_scope)
