# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/scene.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.unity import game_object_pb2 as avikom_dot_unity_dot_game__object__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x61vikom/assistance/scene.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a\x1e\x61vikom/unity/game_object.proto\"K\n\x05Scene\x12\x14\n\x04name\x18\x01 \x01(\tB\x06\x8a\xb5\x18\x02\x10\x01\x12&\n\x05tasks\x18\x02 \x03(\x0b\x32\x17.avikom.assistance.Task:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.scene_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SCENE.fields_by_name['name']._options = None
  _SCENE.fields_by_name['name']._serialized_options = b'\212\265\030\002\020\001'
  _SCENE._options = None
  _SCENE._serialized_options = b'\210\265\030\001'
  _SCENE._serialized_start=144
  _SCENE._serialized_end=219
# @@protoc_insertion_point(module_scope)
