"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _LogLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _LogLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_LogLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    DEBUG: _LogLevel.ValueType  # 0
    """/ default level used for debugging"""
    INFO: _LogLevel.ValueType  # 1
    """/ information that might be of interest to developers also during production"""
    WARN: _LogLevel.ValueType  # 2
    """/ warnings that should be of interest to developers and can foreshadow future errors"""
    ERROR: _LogLevel.ValueType  # 3
    """/ errors that are of interest to developers and break functionality"""
    FATAL: _LogLevel.ValueType  # 4
    """/ erros that result in total or partial system failure"""

class LogLevel(_LogLevel, metaclass=_LogLevelEnumTypeWrapper):
    """
    The LogLevel specifies the criticality of a log
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

DEBUG: LogLevel.ValueType  # 0
"""/ default level used for debugging"""
INFO: LogLevel.ValueType  # 1
"""/ information that might be of interest to developers also during production"""
WARN: LogLevel.ValueType  # 2
"""/ warnings that should be of interest to developers and can foreshadow future errors"""
ERROR: LogLevel.ValueType  # 3
"""/ errors that are of interest to developers and break functionality"""
FATAL: LogLevel.ValueType  # 4
"""/ erros that result in total or partial system failure"""
global___LogLevel = LogLevel

@typing_extensions.final
class Message(google.protobuf.message.Message):
    """
    A message specifying the log combining the log level, the logging message and the origin
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LEVEL_FIELD_NUMBER: builtins.int
    CONTENT_FIELD_NUMBER: builtins.int
    ORIGIN_FIELD_NUMBER: builtins.int
    level: global___LogLevel.ValueType
    """/ holds the log level of the message"""
    content: builtins.str
    """/ holds the log message"""
    origin: builtins.str
    """/ which service issued the log"""
    def __init__(
        self,
        *,
        level: global___LogLevel.ValueType = ...,
        content: builtins.str = ...,
        origin: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["content", b"content", "level", b"level", "origin", b"origin"]) -> None: ...

global___Message = Message
