"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _AssistanceLevel:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _AssistanceLevelEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_AssistanceLevel.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    UNKNOWN: _AssistanceLevel.ValueType  # 0
    """/ representes an unset level; should not be used explicitely"""
    NONE: _AssistanceLevel.ValueType  # 1
    """/ user requires no assistance; instructions assigned to this level are considered mandatory"""
    BRIEF: _AssistanceLevel.ValueType  # 2
    """/ provides some (textual/visual) hooks to remember the step at hand"""
    DEFAULT: _AssistanceLevel.ValueType  # 5
    """/ this should be the experience for new and unknown users"""
    VERBOSE: _AssistanceLevel.ValueType  # 9
    """/ highest demand for assistance; should provide all assistance possible"""

class AssistanceLevel(_AssistanceLevel, metaclass=_AssistanceLevelEnumTypeWrapper):
    """*
    This enum describes the assistance level required by a user or assigned to an instruction.
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

UNKNOWN: AssistanceLevel.ValueType  # 0
"""/ representes an unset level; should not be used explicitely"""
NONE: AssistanceLevel.ValueType  # 1
"""/ user requires no assistance; instructions assigned to this level are considered mandatory"""
BRIEF: AssistanceLevel.ValueType  # 2
"""/ provides some (textual/visual) hooks to remember the step at hand"""
DEFAULT: AssistanceLevel.ValueType  # 5
"""/ this should be the experience for new and unknown users"""
VERBOSE: AssistanceLevel.ValueType  # 9
"""/ highest demand for assistance; should provide all assistance possible"""
global___AssistanceLevel = AssistanceLevel
