# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/issue_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import issue_pb2 as avikom_dot_assistance_dot_issue__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#avikom/assistance/issue_query.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/issue.proto\"Y\n\nIssueQuery\x12\n\n\x02id\x18\x01 \x01(\t\x12.\n\x06status\x18\x02 \x01(\x0e\x32\x1e.avikom.assistance.IssueStatus\x12\x0f\n\x07user_id\x18\x03 \x01(\x04\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.issue_query_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _ISSUEQUERY._serialized_start=89
  _ISSUEQUERY._serialized_end=178
# @@protoc_insertion_point(module_scope)
