# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/session_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.assistance import session_pb2 as avikom_dot_assistance_dot_session__pb2
from avikom.assistance import session_query_pb2 as avikom_dot_assistance_dot_session__query__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n/avikom/assistance/session_storage_service.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1f\x61vikom/assistance/session.proto\x1a%avikom/assistance/session_query.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1bgoogle/protobuf/empty.proto\";\n\x0bSessionList\x12,\n\x08sessions\x18\x01 \x03(\x0b\x32\x1a.avikom.assistance.Session2\x9f\x03\n\x15SessionStorageService\x12\x43\n\x0bSaveSession\x12\x1a.avikom.assistance.Session\x1a\x16.avikom.generic.Result\"\x00\x12l\n\nGetSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x1a.avikom.assistance.Session\"!\x82\xd3\xe4\x93\x02\x1b\x12\x19/v1/storage/sessions/{id}\x12\x66\n\x0eGetAllSessions\x12\x16.google.protobuf.Empty\x1a\x1e.avikom.assistance.SessionList\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/v1/storage/sessions\x12k\n\rDeleteSession\x12\x1f.avikom.assistance.SessionQuery\x1a\x16.avikom.generic.Result\"!\x82\xd3\xe4\x93\x02\x1b*\x19/v1/storage/sessions/{id}Bu\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.session_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SESSIONSTORAGESERVICE.methods_by_name['GetSession']._options = None
  _SESSIONSTORAGESERVICE.methods_by_name['GetSession']._serialized_options = b'\202\323\344\223\002\033\022\031/v1/storage/sessions/{id}'
  _SESSIONSTORAGESERVICE.methods_by_name['GetAllSessions']._options = None
  _SESSIONSTORAGESERVICE.methods_by_name['GetAllSessions']._serialized_options = b'\202\323\344\223\002\026\022\024/v1/storage/sessions'
  _SESSIONSTORAGESERVICE.methods_by_name['DeleteSession']._options = None
  _SESSIONSTORAGESERVICE.methods_by_name['DeleteSession']._serialized_options = b'\202\323\344\223\002\033*\031/v1/storage/sessions/{id}'
  _SESSIONLIST._serialized_start=260
  _SESSIONLIST._serialized_end=319
  _SESSIONSTORAGESERVICE._serialized_start=322
  _SESSIONSTORAGESERVICE._serialized_end=737
# @@protoc_insertion_point(module_scope)
