"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class RasaQuery(google.protobuf.message.Message):
    """*
    A query passed to RasaService
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """/ the id of the user for which information shall be queried"""
    def __init__(
        self,
        *,
        user_id: builtins.int = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["user_id", b"user_id"]) -> None: ...

global___RasaQuery = RasaQuery

@typing_extensions.final
class RasaResult(google.protobuf.message.Message):
    """*
    A list containing intents.
    @author Lars Schalkwijk <lars.schalkwijk@fh-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INTENTS_FIELD_NUMBER: builtins.int
    @property
    def intents(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]:
        """/ a list of intents that can be used to resolve task steps"""
    def __init__(
        self,
        *,
        intents: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["intents", b"intents"]) -> None: ...

global___RasaResult = RasaResult
