# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/step_proficiency.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.options import options_pb2 as avikom_dot_options_dot_options__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2
from avikom.assistance import assistance_level_pb2 as avikom_dot_assistance_dot_assistance__level__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(avikom/assistance/step_proficiency.proto\x12\x11\x61vikom.assistance\x1a\x1c\x61vikom/options/options.proto\x1a!avikom/assistance/task_step.proto\x1a\x19\x61vikom/generic/user.proto\x1a(avikom/assistance/assistance_level.proto\"\x96\x02\n\x0fStepProficiency\x12?\n\x13required_assistance\x18\x01 \x01(\x0e\x32\".avikom.assistance.AssistanceLevel\x12\"\n\x04user\x18\x02 \x01(\x0b\x32\x14.avikom.generic.User\x12)\n\x04step\x18\x03 \x01(\x0b\x32\x1b.avikom.assistance.TaskStep\x12\x10\n\x08tendency\x18\x04 \x01(\x02\x12\x1b\n\x13\x61ssistance_decrease\x18\x05 \x01(\x02\x12>\n\x12minimal_assistance\x18\x06 \x01(\x0e\x32\".avikom.assistance.AssistanceLevel:\x04\x88\xb5\x18\x01\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.step_proficiency_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _STEPPROFICIENCY._options = None
  _STEPPROFICIENCY._serialized_options = b'\210\265\030\001'
  _STEPPROFICIENCY._serialized_start=198
  _STEPPROFICIENCY._serialized_end=476
# @@protoc_insertion_point(module_scope)
