# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/generic/peer_storage_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.generic import peer_pb2 as avikom_dot_generic_dot_peer__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from avikom.generic import user_pb2 as avikom_dot_generic_dot_user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)avikom/generic/peer_storage_service.proto\x12\x0e\x61vikom.generic\x1a\x19\x61vikom/generic/peer.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x19\x61vikom/generic/user.proto\" \n\x10PeerStorageQuery\x12\x0c\n\x04name\x18\x01 \x01(\t2\xd3\x03\n\x12PeerStorageService\x12t\n\nUpdatePeer\x12\x14.avikom.generic.Peer\x1a\x16.avikom.generic.Result\"8\x82\xd3\xe4\x93\x02\x32\x32\x11/v1/storage/peers:\x01*Z\x1a\x32\x18/v1/storage/peers/{name}\x12\x63\n\x07GetPeer\x12 .avikom.generic.PeerStorageQuery\x1a\x14.avikom.generic.Peer\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/v1/storage/peers/{name}\x12\x63\n\x0cGetUserPeers\x12\x14.avikom.generic.User\x1a\x18.avikom.generic.PeerList\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/storage/peers/user/{id}\x12}\n\nDeletePeer\x12 .avikom.generic.PeerStorageQuery\x1a\x16.avikom.generic.Result\"5\x82\xd3\xe4\x93\x02/*\x11/v1/storage/peersZ\x1a*\x18/v1/storage/peers/{name}Bl\n\x18\x61pp.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\xaa\x02\x14\x41vikom.Types.Genericb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.generic.peer_storage_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\030app.avikom.types.genericZ9gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/generic\252\002\024Avikom.Types.Generic'
  _PEERSTORAGESERVICE.methods_by_name['UpdatePeer']._options = None
  _PEERSTORAGESERVICE.methods_by_name['UpdatePeer']._serialized_options = b'\202\323\344\223\00222\021/v1/storage/peers:\001*Z\0322\030/v1/storage/peers/{name}'
  _PEERSTORAGESERVICE.methods_by_name['GetPeer']._options = None
  _PEERSTORAGESERVICE.methods_by_name['GetPeer']._serialized_options = b'\202\323\344\223\002\032\022\030/v1/storage/peers/{name}'
  _PEERSTORAGESERVICE.methods_by_name['GetUserPeers']._options = None
  _PEERSTORAGESERVICE.methods_by_name['GetUserPeers']._serialized_options = b'\202\323\344\223\002\035\022\033/v1/storage/peers/user/{id}'
  _PEERSTORAGESERVICE.methods_by_name['DeletePeer']._options = None
  _PEERSTORAGESERVICE.methods_by_name['DeletePeer']._serialized_options = b'\202\323\344\223\002/*\021/v1/storage/peersZ\032*\030/v1/storage/peers/{name}'
  _PEERSTORAGEQUERY._serialized_start=174
  _PEERSTORAGEQUERY._serialized_end=206
  _PEERSTORAGESERVICE._serialized_start=209
  _PEERSTORAGESERVICE._serialized_end=676
# @@protoc_insertion_point(module_scope)
