"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class AssetBundleQuery(google.protobuf.message.Message):
    """
    A message to request asset bundles from a server.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BUNDLE_NAME_FIELD_NUMBER: builtins.int
    bundle_name: builtins.str
    """/ globally unique name of the bundle"""
    def __init__(
        self,
        *,
        bundle_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["bundle_name", b"bundle_name"]) -> None: ...

global___AssetBundleQuery = AssetBundleQuery
