"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class TargetRequest(google.protobuf.message.Message):
    """*
    This message is used to request an entities location.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    TARGET_FIELD_NUMBER: builtins.int
    SLEEP_MS_FIELD_NUMBER: builtins.int
    WATCHER_FIELD_NUMBER: builtins.int
    target: builtins.str
    """/ the object/entity that should be tracked"""
    sleep_ms: builtins.int
    """/ the sleep interval between messages; should be equal or larger than time needed to process messages; a higher value reduces load on the service and on the network"""
    watcher: builtins.str
    """/ the origin of relative requests"""
    def __init__(
        self,
        *,
        target: builtins.str = ...,
        sleep_ms: builtins.int = ...,
        watcher: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["sleep_ms", b"sleep_ms", "target", b"target", "watcher", b"watcher"]) -> None: ...

global___TargetRequest = TargetRequest
