"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import avikom.vision.image_info_pb2
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Image(google.protobuf.message.Message):
    """*
    This message represents a (chunk of an) image. It may contain an `ImageInfo` header or a chunk of data of an image.
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFO_FIELD_NUMBER: builtins.int
    DATA_FIELD_NUMBER: builtins.int
    @property
    def info(self) -> avikom.vision.image_info_pb2.ImageInfo:
        """/ an information header defining size, dimensions and transfer parameters"""
    data: builtins.bytes
    """/ a series of bytes (size defined by `chunk_size` in `info`) representing a chunk of an image"""
    def __init__(
        self,
        *,
        info: avikom.vision.image_info_pb2.ImageInfo | None = ...,
        data: builtins.bytes = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["info", b"info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["data", b"data", "info", b"info"]) -> None: ...

global___Image = Image
