# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: avikom/assistance/scene_consumer_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from avikom.assistance import scene_pb2 as avikom_dot_assistance_dot_scene__pb2
from avikom.assistance import task_pb2 as avikom_dot_assistance_dot_task__pb2
from avikom.assistance import task_step_pb2 as avikom_dot_assistance_dot_task__step__pb2
from avikom.generic import result_pb2 as avikom_dot_generic_dot_result__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n.avikom/assistance/scene_consumer_service.proto\x12\x11\x61vikom.assistance\x1a\x1d\x61vikom/assistance/scene.proto\x1a\x1c\x61vikom/assistance/task.proto\x1a!avikom/assistance/task_step.proto\x1a\x1b\x61vikom/generic/result.proto\x1a\x1bgoogle/protobuf/empty.proto2\xd4\x01\n\x14SceneConsumerService\x12>\n\x08SetScene\x12\x18.avikom.assistance.Scene\x1a\x16.avikom.generic.Result\"\x00\x12>\n\x08GetScene\x12\x16.google.protobuf.Empty\x1a\x18.avikom.assistance.Scene\"\x00\x12<\n\x07SetTask\x12\x17.avikom.assistance.Task\x1a\x16.avikom.generic.Result\"\x00\x42u\n\x1b\x61pp.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\xaa\x02\x17\x41vikom.Types.Assistanceb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'avikom.assistance.scene_consumer_service_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033app.avikom.types.assistanceZ<gitlab.ub.uni-bielefeld.de/avikom/go-types/avikom/assistance\252\002\027Avikom.Types.Assistance'
  _SCENECONSUMERSERVICE._serialized_start=224
  _SCENECONSUMERSERVICE._serialized_end=436
# @@protoc_insertion_point(module_scope)
