"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class StepProficiencyQuery(google.protobuf.message.Message):
    """
    A query to retrieve `StepProficiencies` for task steps or `SplitProcedureResults` for taks
    @author Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ID_FIELD_NUMBER: builtins.int
    TARGET_NAME_FIELD_NUMBER: builtins.int
    user_id: builtins.int
    """/ ID of the user in question"""
    target_name: builtins.str
    """/ either a task step name (for proficiencies) or a task name (for split procedure results)"""
    def __init__(
        self,
        *,
        user_id: builtins.int = ...,
        target_name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["target_name", b"target_name", "user_id", b"user_id"]) -> None: ...

global___StepProficiencyQuery = StepProficiencyQuery
