"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import sys
import typing

if sys.version_info >= (3, 10):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

class _InteractionType:
    ValueType = typing.NewType("ValueType", builtins.int)
    V: typing_extensions.TypeAlias = ValueType

class _InteractionTypeEnumTypeWrapper(google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[_InteractionType.ValueType], builtins.type):
    DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor
    INTERACTION_UNKNOWN: _InteractionType.ValueType  # 0
    """/ default value; should not be set actively"""
    INTERACTION_TAP: _InteractionType.ValueType  # 1
    """/ a user taps/clicks an element"""
    INTERACTION_HOME: _InteractionType.ValueType  # 2
    """/ a home menu button or return element is activated"""
    INTERACTION_BUTTON_DOWN: _InteractionType.ValueType  # 3
    """/ a button is pushed down"""
    INTERACTION_BUTTON_UP: _InteractionType.ValueType  # 4
    """/ a button is released"""
    INTERACTION_DRAG_START: _InteractionType.ValueType  # 5
    """/ user starts to drag an element"""
    INTERACTION_DRAG_STOP: _InteractionType.ValueType  # 6
    """/ user finished the dragging process"""

class InteractionType(_InteractionType, metaclass=_InteractionTypeEnumTypeWrapper):
    """*
    This enum contains all currently available kinds of interaction users can conduct with their surounding.
    @author: Alexander Neumann <alneuman@techfak.uni-bielefeld.de>
    """

INTERACTION_UNKNOWN: InteractionType.ValueType  # 0
"""/ default value; should not be set actively"""
INTERACTION_TAP: InteractionType.ValueType  # 1
"""/ a user taps/clicks an element"""
INTERACTION_HOME: InteractionType.ValueType  # 2
"""/ a home menu button or return element is activated"""
INTERACTION_BUTTON_DOWN: InteractionType.ValueType  # 3
"""/ a button is pushed down"""
INTERACTION_BUTTON_UP: InteractionType.ValueType  # 4
"""/ a button is released"""
INTERACTION_DRAG_START: InteractionType.ValueType  # 5
"""/ user starts to drag an element"""
INTERACTION_DRAG_STOP: InteractionType.ValueType  # 6
"""/ user finished the dragging process"""
global___InteractionType = InteractionType
